@@ -41,8 +41,7 @@
 #include "gstshaper.h"
 #include "gststatistics.h"
 #include "gsttee.h"
-#include "gsttypefind.h"
-
+#include "gsttypefindelement.h"
 
 struct _elements_entry
 {
@@ -67,8 +66,8 @@ static struct _elements_entry _elements[] = {
   {"md5sink", GST_RANK_NONE, gst_md5sink_get_type},
 #ifndef HAVE_WIN32
   {"multifilesrc", GST_RANK_NONE, gst_multifilesrc_get_type},
-#endif
   {"pipefilter", GST_RANK_NONE, gst_pipefilter_get_type},
+#endif
   {"shaper", GST_RANK_NONE, gst_shaper_get_type},
   {"statistics", GST_RANK_NONE, gst_statistics_get_type},
   {"tee", GST_RANK_NONE, gst_tee_get_type},
