@@ -30,7 +30,9 @@
 #include <stdio.h>
 #include <sys/stat.h>
 #include <fcntl.h>
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
+#endif
 #ifdef HAVE_MMAP
 #include <sys/mman.h>
 #endif
@@ -39,6 +41,16 @@
 
 #include "../gst-i18n-lib.h"
 
+/* FIXME we should be using glib for this */
+#ifndef S_ISREG
+#define S_ISREG(mode) ((mode)&_S_IFREG)
+#endif
+#ifndef S_ISDIR
+#define S_ISDIR(mode) ((mode)&_S_IFDIR)
+#endif
+#ifndef S_ISSOCK
+#define S_ISSOCK(x) (0)
+#endif
 
 /**********************************************************************
  * GStreamer Default File Source
@@ -246,7 +258,7 @@ gst_filesrc_init (GstFileSrc * src)
   src->mapbuf = NULL;
   src->mapsize = DEFAULT_MMAPSIZE;      /* default is 4MB */
 
-  src->seek_happened = FALSE;
+  src->is_regular = FALSE;
 }
 
 static void
@@ -324,6 +336,7 @@ gst_filesrc_set_property (GObject * object, guint prop_id, const GValue * value,
       g_object_notify (G_OBJECT (src), "touch");
       break;
     default:
+      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
   }
 }
@@ -471,11 +484,11 @@ gst_filesrc_map_small_region (GstFileSrc * src, off_t offset, size_t size)
 #ifdef HAVE_MMAP
 /**
  * gst_filesrc_get_mmap:
- * @pad: #GstPad to push a buffer from
+ * @src: #GstElement to get data from
  *
- * Push a new buffer from the filesrc at the current offset.
+ * Returns: a new #GstData from the mmap'd source.
  */
-static GstBuffer *
+static GstData *
 gst_filesrc_get_mmap (GstFileSrc * src)
 {
   GstBuffer *buf = NULL;
@@ -572,7 +585,7 @@ gst_filesrc_get_mmap (GstFileSrc * src)
       mapsize = src->mapsize;
 
       /* double the mapsize as long as the readsize is smaller */
-      while (readsize - (src->curoffset - nextmap) > mapsize) {
+      while (readsize + src->curoffset > nextmap + mapsize) {
         GST_LOG_OBJECT (src, "readsize smaller then mapsize %08x %d",
             readsize, (int) mapsize);
         mapsize <<= 1;
@@ -602,11 +615,11 @@ gst_filesrc_get_mmap (GstFileSrc * src)
   /* we're done, return the buffer */
   g_assert (src->curoffset == GST_BUFFER_OFFSET (buf));
   src->curoffset += GST_BUFFER_SIZE (buf);
-  return buf;
+  return GST_DATA (buf);
 }
 #endif
 
-static GstBuffer *
+static GstData *
 gst_filesrc_get_read (GstFileSrc * src)
 {
   GstBuffer *buf = NULL;
@@ -614,26 +627,40 @@ gst_filesrc_get_read (GstFileSrc * src)
   int ret;
 
   readsize = src->block_size;
-  if (src->curoffset + readsize > src->filelen) {
-    if (!gst_filesrc_check_filesize (src)
-        || src->curoffset + readsize > src->filelen) {
-      readsize = src->filelen - src->curoffset;
+  /* for regular files, we can use the filesize to check how much we
+     can read */
+  if (src->is_regular) {
+    if (src->curoffset + readsize > src->filelen) {
+      if (!gst_filesrc_check_filesize (src)
+          || src->curoffset + readsize > src->filelen) {
+        readsize = src->filelen - src->curoffset;
+      }
     }
   }
 
   buf = gst_buffer_new_and_alloc (readsize);
   g_return_val_if_fail (buf != NULL, NULL);
 
+  GST_LOG_OBJECT (src, "Reading %d bytes", readsize);
   ret = read (src->fd, GST_BUFFER_DATA (buf), readsize);
   if (ret < 0) {
     GST_ELEMENT_ERROR (src, RESOURCE, READ, (NULL), GST_ERROR_SYSTEM);
     return NULL;
   }
-  if (ret < readsize) {
+  /* regular files should have given us what we expected */
+  if (ret < readsize && src->is_regular) {
     GST_ELEMENT_ERROR (src, RESOURCE, READ, (NULL),
         ("unexpected end of file."));
     return NULL;
   }
+  /* other files should eos if they read 0 */
+  if (ret == 0) {
+    GST_DEBUG ("non-regular file hits EOS");
+    gst_buffer_unref (buf);
+    gst_element_set_eos (GST_ELEMENT (src));
+    return GST_DATA (gst_event_new (GST_EVENT_EOS));
+  }
+  readsize = ret;
 
   GST_BUFFER_SIZE (buf) = readsize;
   GST_BUFFER_MAXSIZE (buf) = readsize;
@@ -641,7 +668,7 @@ gst_filesrc_get_read (GstFileSrc * src)
   GST_BUFFER_OFFSET_END (buf) = src->curoffset + readsize;
   src->curoffset += readsize;
 
-  return buf;
+  return GST_DATA (buf);
 }
 
 static GstData *
@@ -660,35 +687,38 @@ gst_filesrc_get (GstPad * pad)
     return GST_DATA (gst_event_new_flush ());
   }
   /* check for seek */
-  if (src->seek_happened) {
+  if (src->need_discont) {
     GstEvent *event;
 
-    src->seek_happened = FALSE;
     GST_DEBUG_OBJECT (src, "sending discont");
     event =
-        gst_event_new_discontinuous (FALSE, GST_FORMAT_BYTES, src->curoffset,
-        NULL);
+        gst_event_new_discontinuous (src->need_discont > 1, GST_FORMAT_BYTES,
+        (guint64) src->curoffset, GST_FORMAT_UNDEFINED);
+    src->need_discont = 0;
     return GST_DATA (event);
   }
 
-  /* check for EOF */
-  g_assert (src->curoffset <= src->filelen);
-  if (src->curoffset == src->filelen) {
-    if (!gst_filesrc_check_filesize (src) || src->curoffset >= src->filelen) {
-      GST_DEBUG_OBJECT (src, "eos %" G_GINT64_FORMAT " %" G_GINT64_FORMAT,
-          src->curoffset, src->filelen);
+  /* check for EOF if it's a regular file */
+  if (src->is_regular) {
+    g_assert (src->curoffset <= src->filelen);
+    if (src->curoffset == src->filelen) {
+      if (!gst_filesrc_check_filesize (src) || src->curoffset >= src->filelen) {
+        GST_DEBUG_OBJECT (src, "eos %" G_GINT64_FORMAT " %" G_GINT64_FORMAT,
+            src->curoffset, src->filelen);
+      }
       gst_element_set_eos (GST_ELEMENT (src));
       return GST_DATA (gst_event_new (GST_EVENT_EOS));
+
     }
   }
 #ifdef HAVE_MMAP
   if (src->using_mmap) {
-    return GST_DATA (gst_filesrc_get_mmap (src));
+    return gst_filesrc_get_mmap (src);
   } else {
-    return GST_DATA (gst_filesrc_get_read (src));
+    return gst_filesrc_get_read (src);
   }
 #else
-  return GST_DATA (gst_filesrc_get_read (src));
+  return gst_filesrc_get_read (src);
 #endif
 }
 
@@ -729,7 +759,8 @@ gst_filesrc_open_file (GstFileSrc * src)
   src->fd = open (src->filename, O_RDONLY);
   if (src->fd < 0) {
     if (errno == ENOENT)
-      GST_ELEMENT_ERROR (src, RESOURCE, NOT_FOUND, (NULL), (NULL));
+      GST_ELEMENT_ERROR (src, RESOURCE, NOT_FOUND, (NULL),
+          ("No such file \"%s\"", src->filename));
     else
       GST_ELEMENT_ERROR (src, RESOURCE, OPEN_READ,
           (_("Could not open file \"%s\" for reading."), src->filename),
@@ -741,9 +772,15 @@ gst_filesrc_open_file (GstFileSrc * src)
 
     fstat (src->fd, &stat_results);
 
-    if (!S_ISREG (stat_results.st_mode)) {
+    if (S_ISDIR (stat_results.st_mode)) {
       GST_ELEMENT_ERROR (src, RESOURCE, OPEN_READ,
-          (_("File \"%s\" isn't a regular file."), src->filename), (NULL));
+          (_("\"%s\" is a directory."), src->filename), (NULL));
+      close (src->fd);
+      return FALSE;
+    }
+    if (S_ISSOCK (stat_results.st_mode)) {
+      GST_ELEMENT_ERROR (src, RESOURCE, OPEN_READ,
+          (_("File \"%s\" is a socket."), src->filename), (NULL));
       close (src->fd);
       return FALSE;
     }
@@ -752,15 +789,20 @@ gst_filesrc_open_file (GstFileSrc * src)
     src->filelen = stat_results.st_size;
 
     src->using_mmap = FALSE;
+
+    /* record if it's a regular (hence seekable and lengthable) file */
+    if (S_ISREG (stat_results.st_mode))
+      src->is_regular = TRUE;
 #ifdef HAVE_MMAP
-    /* allocate the first mmap'd region */
+    /* FIXME: maybe we should only try to mmap if it's a regular file */
+    /* allocate the first mmap'd region if it's a regular file ? */
     src->mapbuf = gst_filesrc_map_region (src, 0, src->mapsize);
     if (src->mapbuf != NULL) {
+      GST_DEBUG_OBJECT (src, "using mmap for file");
       src->using_mmap = TRUE;
     }
 #endif
 
-
     src->curoffset = 0;
 
     GST_FLAG_SET (src, GST_FILESRC_OPEN);
@@ -781,6 +823,7 @@ gst_filesrc_close_file (GstFileSrc * src)
   src->fd = 0;
   src->filelen = 0;
   src->curoffset = 0;
+  src->is_regular = FALSE;
 
   if (src->mapbuf) {
     gst_buffer_unref (src->mapbuf);
@@ -806,11 +849,11 @@ gst_filesrc_change_state (GstElement * element)
         if (!gst_filesrc_open_file (GST_FILESRC (element)))
           return GST_STATE_FAILURE;
       }
+      src->need_discont = 2;
       break;
     case GST_STATE_PAUSED_TO_READY:
       if (GST_FLAG_IS_SET (element, GST_FILESRC_OPEN))
         gst_filesrc_close_file (GST_FILESRC (element));
-      src->seek_happened = TRUE;
       break;
     default:
       break;
@@ -828,11 +871,16 @@ gst_filesrc_srcpad_query (GstPad * pad, GstQueryType type,
 {
   GstFileSrc *src = GST_FILESRC (GST_PAD_PARENT (pad));
 
+  if (*format == GST_FORMAT_DEFAULT)
+    *format = GST_FORMAT_BYTES;
+
   switch (type) {
     case GST_QUERY_TOTAL:
       if (*format != GST_FORMAT_BYTES) {
         return FALSE;
       }
+      if (!src->is_regular)
+        return FALSE;
       gst_filesrc_check_filesize (src);
       *value = src->filelen;
       break;
@@ -844,6 +892,8 @@ gst_filesrc_srcpad_query (GstPad * pad, GstQueryType type,
         case GST_FORMAT_PERCENT:
           if (src->filelen == 0)
             return FALSE;
+          if (!src->is_regular)
+            return FALSE;
           *value = src->curoffset * GST_FORMAT_PERCENT_MAX / src->filelen;
           break;
         default:
@@ -872,6 +922,10 @@ gst_filesrc_srcpad_event (GstPad * pad, GstEvent * event)
       if (GST_EVENT_SEEK_FORMAT (event) != GST_FORMAT_BYTES) {
         goto error;
       }
+      if (!src->is_regular) {
+        GST_DEBUG ("can't handle seek on a non-regular file");
+        goto error;
+      }
 
       offset = GST_EVENT_SEEK_OFFSET (event);
 
@@ -910,7 +964,7 @@ gst_filesrc_srcpad_event (GstPad * pad, GstEvent * event)
           goto error;
           break;
       }
-      src->seek_happened = TRUE;
+      src->need_discont = 1;
       src->need_flush = GST_EVENT_SEEK_FLAGS (event) & GST_SEEK_FLAG_FLUSH;
       break;
     }
