@@ -33,20 +33,20 @@
 
 #include <gst/gstbin.h>
 #include <gst/gstbuffer.h>
-#include <gst/gstbufferpool-default.h>
 #include <gst/gstcaps.h>
 #include <gst/gstclock.h>
 #include <gst/gstcpu.h>
 #include <gst/gstelement.h>
+#include <gst/gsterror.h>
 #include <gst/gstevent.h>
 #include <gst/gstindex.h>
 #include <gst/gstinfo.h>
 #include <gst/gstinterface.h>
+#include <gst/gstmarshal.h>
 #include <gst/gstobject.h>
 #include <gst/gstpad.h>
 #include <gst/gstpipeline.h>
 #include <gst/gstplugin.h>
-#include <gst/gstprops.h>
 #include <gst/gstscheduler.h>
 #include <gst/gststructure.h>
 #include <gst/gstsystemclock.h>
@@ -70,17 +70,21 @@
 
 G_BEGIN_DECLS
 
+/* make our own type for poptOption because the struct poptOption
+ * definition is iffy */
+typedef struct poptOption GstPoptOption;
+
 /* initialize GST */
 void		gst_init			(int *argc, char **argv[]);
 gboolean	gst_init_check			(int *argc, char **argv[]);
 void		gst_init_with_popt_table	(int *argc, char **argv[],
-						 const struct poptOption
+						 const GstPoptOption
 						 *popt_options);
 gboolean	gst_init_check_with_popt_table	(int *argc, char **argv[],
-						 const struct poptOption
+						 const GstPoptOption
 						 *popt_options);
-G_CONST_RETURN struct poptOption*
-		gst_init_get_popt_table		(void);
+
+const GstPoptOption *	gst_init_get_popt_table		(void);
 
 void		gst_use_threads			(gboolean use_threads);
 gboolean	gst_has_threads			(void);
@@ -90,6 +94,4 @@ void		gst_main_quit			(void);
 
 G_END_DECLS
 
-#include <gst/gstlog.h>
-
 #endif /* __GST_H__ */
