@@ -548,9 +548,17 @@ gst_bin_remove_func (GstBin * bin, GstElement * element)
   gst_object_unparent (GST_OBJECT (element));
 
   /* if we're down to zero children, force state to NULL */
-  if (bin->numchildren == 0 && GST_ELEMENT_SCHED (bin) != NULL) {
-    GST_STATE_PENDING (bin) = GST_STATE_NULL;
+  while (bin->numchildren == 0 && GST_ELEMENT_SCHED (bin) != NULL &&
+      GST_STATE (bin) > GST_STATE_NULL) {
+    GstElementState next = GST_STATE (bin) >> 1;
+
+    GST_STATE_PENDING (bin) = next;
     gst_bin_change_state_norecurse (bin);
+    if (!GST_STATE (bin) == next) {
+      g_warning ("bin %s failed state change to %d", GST_ELEMENT_NAME (bin),
+          next);
+      break;
+    }
   }
   g_signal_emit (G_OBJECT (bin), gst_bin_signals[ELEMENT_REMOVED], 0, element);
 
@@ -731,10 +739,11 @@ gst_bin_change_state (GstElement * element)
     GstElementState old_child_state;
 
     child = GST_ELEMENT (children->data);
-    children = g_list_next (children);
 
-    if (GST_FLAG_IS_SET (child, GST_ELEMENT_LOCKED_STATE))
+    if (GST_FLAG_IS_SET (child, GST_ELEMENT_LOCKED_STATE)) {
+      children = g_list_next (children);
       continue;
+    }
 
     old_child_state = GST_STATE (child);
 
@@ -772,6 +781,10 @@ gst_bin_change_state (GstElement * element)
             gst_element_state_get_name (pending));
         break;
     }
+    /* we need to do this down here, because there might be elements removed 
+     * from this bin during state changes, so g_list_next (children) might
+     * change as well */
+    children = g_list_next (children);
   }
 
   GST_CAT_DEBUG_OBJECT (GST_CAT_STATES, element,
@@ -810,26 +823,17 @@ static void
 gst_bin_dispose (GObject * object)
 {
   GstBin *bin = GST_BIN (object);
-  GList *children, *orig;
-  GstElement *child;
 
-  GST_CAT_DEBUG (GST_CAT_REFCOUNTING, "dispose");
+  GST_CAT_DEBUG_OBJECT (GST_CAT_REFCOUNTING, object, "dispose");
 
   if (gst_element_get_state (GST_ELEMENT (object)) == GST_STATE_PLAYING)
     gst_element_set_state (GST_ELEMENT (object), GST_STATE_PAUSED);
 
-  if (bin->children) {
-    orig = children = g_list_copy (bin->children);
-    while (children) {
-      child = GST_ELEMENT (children->data);
-      gst_bin_remove (bin, child);
-      children = g_list_next (children);
-    }
-    g_list_free (bin->children);
-    g_list_free (orig);
+  while (bin->children) {
+    gst_bin_remove (bin, GST_ELEMENT (bin->children->data));
   }
-  bin->children = NULL;
-  bin->numchildren = 0;
+  g_assert (bin->children == NULL);
+  g_assert (bin->numchildren == 0);
 
   G_OBJECT_CLASS (parent_class)->dispose (object);
 }
@@ -1108,17 +1112,35 @@ gst_bin_restore_thyself (GstObject * object, xmlNodePtr self)
 static gboolean
 gst_bin_iterate_func (GstBin * bin)
 {
+  GstScheduler *sched = GST_ELEMENT_SCHED (bin);
+
   /* only iterate if this is the manager bin */
-  if (GST_ELEMENT_SCHED (bin) &&
-      GST_ELEMENT_SCHED (bin)->parent == GST_ELEMENT (bin)) {
+  if (sched && sched->parent == GST_ELEMENT (bin)) {
     GstSchedulerState state;
 
-    state = gst_scheduler_iterate (GST_ELEMENT_SCHED (bin));
+    state = gst_scheduler_iterate (sched);
 
     if (state == GST_SCHEDULER_STATE_RUNNING) {
       return TRUE;
     } else if (state == GST_SCHEDULER_STATE_ERROR) {
       gst_element_set_state (GST_ELEMENT (bin), GST_STATE_PAUSED);
+    } else if (state == GST_SCHEDULER_STATE_STOPPED) {
+      /* check if we have children scheds that are still running */
+      /* FIXME: remove in 0.9? autouseless because iterations gone? */
+      GList *walk;
+
+      for (walk = sched->schedulers; walk; walk = g_list_next (walk)) {
+        GstScheduler *test = walk->data;
+
+        g_return_val_if_fail (test->parent, FALSE);
+        if (GST_STATE (test->parent) == GST_STATE_PLAYING) {
+          GST_CAT_DEBUG_OBJECT (GST_CAT_SCHEDULING, bin,
+              "current bin is not iterating, but children are, "
+              "so returning TRUE anyway...");
+          g_usleep (1);
+          return TRUE;
+        }
+      }
     }
   } else {
     g_warning ("bin \"%s\" is not the managing bin, can't be iterated on!\n",
@@ -1145,26 +1167,14 @@ gst_bin_iterate (GstBin * bin)
   g_return_val_if_fail (bin != NULL, FALSE);
   g_return_val_if_fail (GST_IS_BIN (bin), FALSE);
 
-  GST_CAT_LOG_OBJECT (GST_CAT_DATAFLOW, bin, "starting iteration");
-
+  GST_CAT_LOG_OBJECT (GST_CAT_SCHEDULING, bin, "starting iteration");
   gst_object_ref (GST_OBJECT (bin));
 
   running = FALSE;
   g_signal_emit (G_OBJECT (bin), gst_bin_signals[ITERATE], 0, &running);
 
-  GST_CAT_LOG_OBJECT (GST_CAT_DATAFLOW, bin, "finished iteration");
-
-  if (!running) {
-    if (GST_STATE (bin) == GST_STATE_PLAYING &&
-        GST_STATE_PENDING (bin) == GST_STATE_VOID_PENDING) {
-      GST_CAT_DEBUG (GST_CAT_DATAFLOW,
-          "[%s]: polling for child shutdown after useless iteration",
-          GST_ELEMENT_NAME (bin));
-      g_usleep (1);
-      running = TRUE;
-    }
-  }
   gst_object_unref (GST_OBJECT (bin));
+  GST_CAT_LOG_OBJECT (GST_CAT_SCHEDULING, bin, "finished iteration");
 
   return running;
 }
