@@ -21,7 +21,9 @@
 #include "config.h"
 #endif
 #include <string.h>
+#include <signal.h>
 
+#include "gst_private.h"
 #include <gst/gst.h>
 
 #define CAPS_POISON(caps) G_STMT_START{ \
@@ -85,7 +87,7 @@ gst_caps_new_empty (void)
 }
 
 /**
- * gst_caps_new_empty:
+ * gst_caps_new_any:
  *
  * Creates a new #GstCaps that indicates that it is compatible with
  * any media format.
@@ -95,10 +97,8 @@ gst_caps_new_empty (void)
 GstCaps *
 gst_caps_new_any (void)
 {
-  GstCaps *caps = g_new0 (GstCaps, 1);
+  GstCaps *caps = gst_caps_new_empty ();
 
-  caps->type = GST_TYPE_CAPS;
-  caps->structs = g_ptr_array_new ();
   caps->flags = GST_CAPS_FLAGS_ANY;
 
   return caps;
@@ -107,6 +107,7 @@ gst_caps_new_any (void)
 /**
  * gst_caps_new_simple:
  * @media_type: the media type of the structure
+ * @fieldname: first field to set
  * @...: additional arguments
  *
  * Creates a new #GstCaps that contains one #GstStructure.  The
@@ -122,9 +123,7 @@ gst_caps_new_simple (const char *media_type, const char *fieldname, ...)
   GstStructure *structure;
   va_list var_args;
 
-  caps = g_new0 (GstCaps, 1);
-  caps->type = GST_TYPE_CAPS;
-  caps->structs = g_ptr_array_new ();
+  caps = gst_caps_new_empty ();
 
   va_start (var_args, fieldname);
   structure = gst_structure_new_valist (media_type, fieldname, var_args);
@@ -161,7 +160,7 @@ gst_caps_new_full (GstStructure * struct1, ...)
 
 /**
  * gst_caps_new_full_valist:
- * @struct1: the first structure to add
+ * @structure: the first structure to add
  * @var_args: additional structures to add
  *
  * Creates a new #GstCaps and adds all the structures listed as
@@ -175,9 +174,7 @@ gst_caps_new_full_valist (GstStructure * structure, va_list var_args)
 {
   GstCaps *caps;
 
-  caps = g_new0 (GstCaps, 1);
-  caps->type = GST_TYPE_CAPS;
-  caps->structs = g_ptr_array_new ();
+  caps = gst_caps_new_empty ();
 
   while (structure) {
     gst_caps_append_structure (caps, structure);
@@ -203,12 +200,10 @@ gst_caps_copy (const GstCaps * caps)
   GstStructure *structure;
   int i;
 
-  g_return_val_if_fail (caps != NULL, NULL);
+  g_return_val_if_fail (GST_IS_CAPS (caps), NULL);
 
-  newcaps = g_new0 (GstCaps, 1);
-  newcaps->type = GST_TYPE_CAPS;
+  newcaps = gst_caps_new_empty ();
   newcaps->flags = caps->flags;
-  newcaps->structs = g_ptr_array_new ();
 
   for (i = 0; i < caps->structs->len; i++) {
     structure = gst_caps_get_structure (caps, i);
@@ -231,7 +226,7 @@ gst_caps_free (GstCaps * caps)
   GstStructure *structure;
   int i;
 
-  g_return_if_fail (caps != NULL);
+  g_return_if_fail (GST_IS_CAPS (caps));
 
   for (i = 0; i < caps->structs->len; i++) {
     structure = gst_caps_get_structure (caps, i);
@@ -288,15 +283,24 @@ gst_caps_append (GstCaps * caps1, GstCaps * caps2)
   GstStructure *structure;
   int i;
 
-  g_return_if_fail (caps1 != NULL);
-  g_return_if_fail (caps2 != NULL);
+  g_return_if_fail (GST_IS_CAPS (caps1));
+  g_return_if_fail (GST_IS_CAPS (caps2));
 
 #ifdef USE_POISONING
   CAPS_POISON (caps2);
 #endif
-  for (i = 0; i < caps2->structs->len; i++) {
-    structure = gst_caps_get_structure (caps2, i);
-    gst_caps_append_structure (caps1, structure);
+  if (gst_caps_is_any (caps1) || gst_caps_is_any (caps2)) {
+    /* FIXME: this leaks */
+    caps1->flags |= GST_CAPS_FLAGS_ANY;
+    for (i = 0; i < caps2->structs->len; i++) {
+      structure = gst_caps_get_structure (caps2, i);
+      gst_structure_remove_all_fields (structure);
+    }
+  } else {
+    for (i = 0; i < caps2->structs->len; i++) {
+      structure = gst_caps_get_structure (caps2, i);
+      gst_caps_append_structure (caps1, structure);
+    }
   }
   g_ptr_array_free (caps2->structs, TRUE);
 #ifdef USE_POISONING
@@ -310,13 +314,13 @@ gst_caps_append (GstCaps * caps1, GstCaps * caps2)
  * @caps: the #GstCaps that will be appended to
  * @structure: the #GstStructure to append
  *
- * Appends @structure to @caps1.  The structure is not copied; @caps1
+ * Appends @structure to @caps.  The structure is not copied; @caps
  * becomes the owner of @structure.
  */
 void
 gst_caps_append_structure (GstCaps * caps, GstStructure * structure)
 {
-  g_return_if_fail (caps != NULL);
+  g_return_if_fail (GST_IS_CAPS (caps));
 
   if (structure) {
 #if 0
@@ -328,10 +332,39 @@ gst_caps_append_structure (GstCaps * caps, GstStructure * structure)
   }
 }
 
+static GstStructure *
+gst_caps_remove_and_get_structure (GstCaps * caps, guint idx)
+{
+  /* don't use index_fast, gst_caps_simplify relies on the order */
+  return g_ptr_array_remove_index (caps->structs, idx);
+}
+
+/*
+ * gst_caps_remove_structure:
+ * @caps: the #GstCaps to remove from
+ * @idx: Index of the structure to remove
+ *
+ * removes the stucture with the given index from the list of structures 
+ * contained in @caps.
+ */
+void
+gst_caps_remove_structure (GstCaps * caps, guint idx)
+{
+  GstStructure *structure;
+
+  g_return_if_fail (caps != NULL);
+  g_return_if_fail (idx <= gst_caps_get_size (caps));
+
+  structure = gst_caps_remove_and_get_structure (caps, idx);
+  gst_structure_free (structure);
+}
+
 /**
  * gst_caps_split_one:
  * @caps: 
  *
+ * This function is not implemented.
+ *
  * Returns:
  */
 GstCaps *
@@ -344,15 +377,17 @@ gst_caps_split_one (GstCaps * caps)
 }
 
 /**
- * gst_caps_split_one:
+ * gst_caps_get_size:
  * @caps: a #GstCaps
  *
+ * Gets the number of structures contained in @caps.
+ *
  * Returns: the number of structures that @caps contains
  */
 int
 gst_caps_get_size (const GstCaps * caps)
 {
-  g_return_val_if_fail (caps != NULL, 0);
+  g_return_val_if_fail (GST_IS_CAPS (caps), 0);
 
   return caps->structs->len;
 }
@@ -375,7 +410,7 @@ gst_caps_get_size (const GstCaps * caps)
 GstStructure *
 gst_caps_get_structure (const GstCaps * caps, int index)
 {
-  g_return_val_if_fail (caps != NULL, NULL);
+  g_return_val_if_fail (GST_IS_CAPS (caps), NULL);
   g_return_val_if_fail (index >= 0, NULL);
   g_return_val_if_fail (index < caps->structs->len, NULL);
 
@@ -397,12 +432,10 @@ gst_caps_copy_1 (const GstCaps * caps)
   GstCaps *newcaps;
   GstStructure *structure;
 
-  g_return_val_if_fail (caps != NULL, NULL);
+  g_return_val_if_fail (GST_IS_CAPS (caps), NULL);
 
-  newcaps = g_new0 (GstCaps, 1);
-  newcaps->type = GST_TYPE_CAPS;
+  newcaps = gst_caps_new_empty ();
   newcaps->flags = caps->flags;
-  newcaps->structs = g_ptr_array_new ();
 
   if (caps->structs->len > 0) {
     structure = gst_caps_get_structure (caps, 0);
@@ -428,7 +461,7 @@ gst_caps_set_simple (GstCaps * caps, char *field, ...)
   GstStructure *structure;
   va_list var_args;
 
-  g_return_if_fail (caps != NULL);
+  g_return_if_fail (GST_IS_CAPS (caps));
   g_return_if_fail (caps->structs->len == 1);
 
   structure = gst_caps_get_structure (caps, 0);
@@ -453,7 +486,7 @@ gst_caps_set_simple_valist (GstCaps * caps, char *field, va_list varargs)
 {
   GstStructure *structure;
 
-  g_return_if_fail (caps != NULL);
+  g_return_if_fail (GST_IS_CAPS (caps));
   g_return_if_fail (caps->structs->len != 1);
 
   structure = gst_caps_get_structure (caps, 0);
@@ -467,12 +500,14 @@ gst_caps_set_simple_valist (GstCaps * caps, char *field, va_list varargs)
  * gst_caps_is_any:
  * @caps: the @GstCaps to test
  *
+ * Determines if @caps represents any media format.
+ *
  * Returns: TRUE if @caps represents any format.
  */
 gboolean
 gst_caps_is_any (const GstCaps * caps)
 {
-  g_return_val_if_fail (caps != NULL, FALSE);
+  g_return_val_if_fail (GST_IS_CAPS (caps), FALSE);
 
   return (caps->flags & GST_CAPS_FLAGS_ANY);
 }
@@ -481,12 +516,14 @@ gst_caps_is_any (const GstCaps * caps)
  * gst_caps_is_empty:
  * @caps: the @GstCaps to test
  *
+ * Determines if @caps represents no media formats.
+ *
  * Returns: TRUE if @caps represents no formats.
  */
 gboolean
 gst_caps_is_empty (const GstCaps * caps)
 {
-  g_return_val_if_fail (caps != NULL, FALSE);
+  g_return_val_if_fail (GST_IS_CAPS (caps), FALSE);
 
   if (caps->flags & GST_CAPS_FLAGS_ANY)
     return FALSE;
@@ -498,12 +535,17 @@ gst_caps_is_empty (const GstCaps * caps)
  * gst_caps_is_chained:
  * @caps: the @GstCaps to test
  *
+ * Determines if @caps contains multiple #GstStructures.
+ *
+ * This function is deprecated, and should not be used in new code.
+ * Use #gst_caps_is_simple() instead.
+ *
  * Returns: TRUE if @caps contains more than one structure
  */
 gboolean
 gst_caps_is_chained (const GstCaps * caps)
 {
-  g_return_val_if_fail (caps != NULL, FALSE);
+  g_return_val_if_fail (GST_IS_CAPS (caps), FALSE);
 
   return (caps->structs->len > 1);
 }
@@ -513,11 +555,7 @@ gst_caps_is_fixed_foreach (GQuark field_id, GValue * value, gpointer unused)
 {
   GType type = G_VALUE_TYPE (value);
 
-  if (G_TYPE_IS_FUNDAMENTAL (type))
-    return TRUE;
-  if (type == GST_TYPE_FOURCC)
-    return TRUE;
-  return FALSE;
+  return gst_type_is_fixed (type);
 }
 
 /**
@@ -535,7 +573,7 @@ gst_caps_is_fixed (const GstCaps * caps)
 {
   GstStructure *structure;
 
-  g_return_val_if_fail (caps != NULL, FALSE);
+  g_return_val_if_fail (GST_IS_CAPS (caps), FALSE);
 
   if (caps->structs->len != 1)
     return FALSE;
@@ -592,87 +630,78 @@ gst_caps_is_equal_fixed (const GstCaps * caps1, const GstCaps * caps2)
       struct2);
 }
 
-static gboolean
-gst_structure_field_has_compatible (GQuark field_id,
-    GValue * val2, gpointer data)
-{
-  GValue dest = { 0 };
-  GstStructure *struct1 = (GstStructure *) data;
-  const GValue *val1 = gst_structure_id_get_value (struct1, field_id);
-
-  if (val1 == NULL)
-    return FALSE;
-  if (gst_value_intersect (&dest, val1, val2)) {
-    g_value_unset (&dest);
-    return TRUE;
-  }
-
-  return FALSE;
-}
-
-static gboolean
-gst_cap_is_always_compatible (const GstStructure * struct1,
-    const GstStructure * struct2)
-{
-  if (struct1->name != struct2->name) {
-    return FALSE;
-  }
-
-  /* the reversed order is important */
-  return gst_structure_foreach ((GstStructure *) struct2,
-      gst_structure_field_has_compatible, (gpointer) struct1);
-}
-
-static gboolean
-gst_caps_cap_is_always_compatible (const GstStructure * struct1,
-    const GstCaps * caps2)
-{
-  int i;
-
-  for (i = 0; i < caps2->structs->len; i++) {
-    GstStructure *struct2 = gst_caps_get_structure (caps2, i);
-
-    if (gst_cap_is_always_compatible (struct1, struct2)) {
-      return TRUE;
-    }
-  }
-
-  return FALSE;
-}
-
 /**
- * gst_caps_is_always_compatible
+ * gst_caps_is_always_compatible:
  * @caps1: the #GstCaps to test
  * @caps2: the #GstCaps to test
  *
+ * A given #GstCaps structure is always compatible with another if
+ * every media format that is in the first is also contained in the
+ * second.  That is, @caps1 is a subset of @caps2.
+ *
  * Returns: TRUE if @caps1 is a subset of @caps2.
  */
 gboolean
 gst_caps_is_always_compatible (const GstCaps * caps1, const GstCaps * caps2)
 {
-  int i;
+  g_return_val_if_fail (GST_IS_CAPS (caps1), FALSE);
+  g_return_val_if_fail (GST_IS_CAPS (caps2), FALSE);
 
-  g_return_val_if_fail (caps1 != NULL, FALSE);
-  g_return_val_if_fail (caps2 != NULL, FALSE);
-  /* FIXME: is this right ? */
-  g_return_val_if_fail (!gst_caps_is_empty (caps1), FALSE);
-  g_return_val_if_fail (!gst_caps_is_empty (caps2), FALSE);
+  return gst_caps_is_subset (caps1, caps2);
+}
 
-  if (gst_caps_is_any (caps2))
+/**
+ * gst_caps_is_subset:
+ * @subset: a #GstCaps
+ * @superset: a potentially greater #GstCaps
+ *
+ * Checks if all caps represented by @subset are also represented by @superset
+ * <note>This function does not work reliably if optional properties for caps
+ * are included on one caps and omitted on the other.</note>
+ *
+ * Returns: TRUE if @subset is a subset of @superset
+ */
+gboolean
+gst_caps_is_subset (const GstCaps * subset, const GstCaps * superset)
+{
+  GstCaps *caps;
+  gboolean ret;
+
+  g_return_val_if_fail (subset != NULL, FALSE);
+  g_return_val_if_fail (superset != NULL, FALSE);
+
+  if (gst_caps_is_empty (subset) || gst_caps_is_any (superset))
     return TRUE;
-  if (gst_caps_is_any (caps1))
+  if (gst_caps_is_any (subset) || gst_caps_is_empty (superset))
     return FALSE;
 
-  for (i = 0; i < caps1->structs->len; i++) {
-    GstStructure *struct1 = gst_caps_get_structure (caps1, i);
+  caps = gst_caps_subtract (subset, superset);
+  ret = gst_caps_is_empty (caps);
+  gst_caps_free (caps);
+  return ret;
+}
 
-    if (gst_caps_cap_is_always_compatible (struct1, caps2) == FALSE) {
-      return FALSE;
-    }
+/**
+ * gst_caps_is_equal:
+ * @caps1: a #GstCaps
+ * @caps2: another #GstCaps
+ *
+ * Checks if the given caps represent the same set of caps.
+ * <note>This function does not work reliably if optional properties for caps
+ * are included on one caps and omitted on the other.</note>
+ *
+ * Returns: TRUE if both caps are equal
+ */
+gboolean
+gst_caps_is_equal (const GstCaps * caps1, const GstCaps * caps2)
+{
+  g_return_val_if_fail (caps1 != NULL, FALSE);
+  g_return_val_if_fail (caps2 != NULL, FALSE);
 
-  }
+  if (gst_caps_is_fixed (caps1) && gst_caps_is_fixed (caps2))
+    return gst_caps_is_equal_fixed (caps1, caps2);
 
-  return FALSE;
+  return gst_caps_is_subset (caps1, caps2) && gst_caps_is_subset (caps2, caps1);
 }
 
 typedef struct
@@ -680,7 +709,8 @@ typedef struct
   GstStructure *dest;
   const GstStructure *intersect;
   gboolean first_run;
-} IntersectData;
+}
+IntersectData;
 
 static gboolean
 gst_caps_structure_intersect_field (GQuark id, GValue * val1, gpointer data)
@@ -795,12 +825,8 @@ gst_caps_intersect (const GstCaps * caps1, const GstCaps * caps2)
   GstStructure *struct2;
   GstCaps *dest;
 
-#if 0
-  GstCaps *caps;
-#endif
-
-  g_return_val_if_fail (caps1 != NULL, NULL);
-  g_return_val_if_fail (caps2 != NULL, NULL);
+  g_return_val_if_fail (GST_IS_CAPS (caps1), NULL);
+  g_return_val_if_fail (GST_IS_CAPS (caps2), NULL);
 
   if (gst_caps_is_empty (caps1) || gst_caps_is_empty (caps2)) {
     return gst_caps_new_empty ();
@@ -823,14 +849,140 @@ gst_caps_intersect (const GstCaps * caps1, const GstCaps * caps2)
     }
   }
 
-#if 0
-  caps = gst_caps_simplify (dest);
-  gst_caps_free (dest);
+  gst_caps_do_simplify (dest);
+  return dest;
+}
 
-  return caps;
-#else
+typedef struct
+{
+  const GstStructure *subtract_from;
+  GSList *put_into;
+}
+SubtractionEntry;
+
+
+gboolean
+gst_caps_structure_subtract_field (GQuark field_id, GValue * value,
+    gpointer user_data)
+{
+  SubtractionEntry *e = user_data;
+  GValue subtraction = { 0, };
+  const GValue *other;
+  GstStructure *structure;
+
+  other = gst_structure_id_get_value (e->subtract_from, field_id);
+  if (!other) {
+    return FALSE;
+  }
+  if (!gst_value_subtract (&subtraction, other, value))
+    return TRUE;
+  if (gst_value_compare (&subtraction, other) == GST_VALUE_EQUAL) {
+    g_value_unset (&subtraction);
+    return FALSE;
+  } else {
+    structure = gst_structure_copy (e->subtract_from);
+    gst_structure_id_set_value (structure, field_id, &subtraction);
+    g_value_unset (&subtraction);
+    e->put_into = g_slist_prepend (e->put_into, structure);
+    return TRUE;
+  }
+}
+
+static gboolean
+gst_caps_structure_subtract (GSList ** into, const GstStructure * minuend,
+    const GstStructure * subtrahend)
+{
+  SubtractionEntry e;
+  gboolean ret;
+
+  e.subtract_from = minuend;
+  e.put_into = NULL;
+
+  ret = gst_structure_foreach ((GstStructure *) subtrahend,
+      gst_caps_structure_subtract_field, &e);
+  if (ret) {
+    *into = e.put_into;
+  } else {
+    GSList *walk;
+
+    for (walk = e.put_into; walk; walk = g_slist_next (walk)) {
+      gst_structure_free (walk->data);
+    }
+    g_slist_free (e.put_into);
+  }
+  return ret;
+}
+
+/**
+ * gst_caps_subtract:
+ * @minuend: #GstCaps to substract from
+ * @subtrahend: #GstCaps to substract
+ *
+ * Subtracts the @subtrahend from the @minuend.
+ * <note>This function does not work reliably if optional properties for caps
+ * are included on one caps and omitted on the other.</note>
+ *
+ * Returns: the resulting caps
+ */
+GstCaps *
+gst_caps_subtract (const GstCaps * minuend, const GstCaps * subtrahend)
+{
+  int i, j;
+  GstStructure *min;
+  GstStructure *sub;
+  GstCaps *dest = NULL, *src;
+
+  g_return_val_if_fail (minuend != NULL, NULL);
+  g_return_val_if_fail (subtrahend != NULL, NULL);
+
+  if (gst_caps_is_empty (minuend) || gst_caps_is_any (subtrahend)) {
+    return gst_caps_new_empty ();
+  }
+  if (gst_caps_is_empty (subtrahend))
+    return gst_caps_copy (minuend);
+
+  /* FIXME: Do we want this here or above?
+     The reason we need this is that there is no definition about what
+     ANY means for specific types, so it's not possible to reduce ANY partially
+     You can only remove everything or nothing and that is done above.
+     Note: there's a test that checks this behaviour. */
+  g_return_val_if_fail (!gst_caps_is_any (minuend), NULL);
+  g_assert (subtrahend->structs->len > 0);
+
+  src = gst_caps_copy (minuend);
+  for (i = 0; i < subtrahend->structs->len; i++) {
+    sub = gst_caps_get_structure (subtrahend, i);
+    if (dest) {
+      gst_caps_free (src);
+      src = dest;
+    }
+    dest = gst_caps_new_empty ();
+    for (j = 0; j < src->structs->len; j++) {
+      min = gst_caps_get_structure (src, j);
+      if (gst_structure_get_name_id (min) == gst_structure_get_name_id (sub)) {
+        GSList *list;
+
+        if (gst_caps_structure_subtract (&list, min, sub)) {
+          GSList *walk;
+
+          for (walk = list; walk; walk = g_slist_next (walk)) {
+            gst_caps_append_structure (dest, (GstStructure *) walk->data);
+          }
+          g_slist_free (list);
+        } else {
+          gst_caps_append_structure (dest, gst_structure_copy (min));
+        }
+      } else {
+        gst_caps_append_structure (dest, gst_structure_copy (min));
+      }
+    }
+    if (gst_caps_is_empty (dest))
+      return dest;
+  }
+
+  gst_caps_free (src);
+  gst_caps_do_simplify (dest);
   return dest;
-#endif
 }
 
 /**
@@ -849,12 +1001,14 @@ gst_caps_union (const GstCaps * caps1, const GstCaps * caps2)
   GstCaps *dest1;
   GstCaps *dest2;
 
+  if (gst_caps_is_any (caps1) || gst_caps_is_any (caps2))
+    return gst_caps_new_any ();
+
   dest1 = gst_caps_copy (caps1);
   dest2 = gst_caps_copy (caps2);
   gst_caps_append (dest1, dest2);
 
-  /* FIXME: need a simplify function */
-
+  gst_caps_do_simplify (dest1);
   return dest1;
 }
 
@@ -862,7 +1016,8 @@ typedef struct _NormalizeForeach
 {
   GstCaps *caps;
   GstStructure *structure;
-} NormalizeForeach;
+}
+NormalizeForeach;
 
 static gboolean
 gst_caps_normalize_foreach (GQuark field_id, GValue * value, gpointer ptr)
@@ -906,7 +1061,7 @@ gst_caps_normalize (const GstCaps * caps)
   GstCaps *newcaps;
   int i;
 
-  g_return_val_if_fail (caps != NULL, NULL);
+  g_return_val_if_fail (GST_IS_CAPS (caps), NULL);
 
   newcaps = gst_caps_copy (caps);
   nf.caps = newcaps;
@@ -921,33 +1076,21 @@ gst_caps_normalize (const GstCaps * caps)
   return newcaps;
 }
 
-static gboolean
-simplify_foreach (GQuark field_id, GValue * value, gpointer user_data)
+static gint
+gst_caps_compare_structures (gconstpointer one, gconstpointer two)
 {
-  GstStructure *s2 = (GstStructure *) user_data;
-  const GValue *v2;
+  gint ret;
+  const GstStructure *struct1 = *((const GstStructure **) one);
+  const GstStructure *struct2 = *((const GstStructure **) two);
 
-  v2 = gst_structure_id_get_value (s2, field_id);
-  if (v2 == NULL)
-    return FALSE;
+  /* FIXME: this orders aphabetically, but ordering the quarks might be faster 
+     So what's the best way? */
+  ret = strcmp (gst_structure_get_name (struct1),
+      gst_structure_get_name (struct2));
+  if (ret)
+    return ret;
 
-  if (gst_value_compare (value, v2) == GST_VALUE_EQUAL)
-    return TRUE;
-  return FALSE;
-}
-
-static gboolean
-gst_caps_structure_simplify (GstStructure * struct1,
-    const GstStructure * struct2)
-{
-  /* FIXME this is just a simple compare.  Better would be to merge
-   * the two structures */
-  if (struct1->name != struct2->name)
-    return FALSE;
-  if (struct1->fields->len != struct2->fields->len)
-    return FALSE;
-
-  return gst_structure_foreach (struct1, simplify_foreach, (void *) struct2);
+  return gst_structure_n_fields (struct2) - gst_structure_n_fields (struct1);
 }
 
 /**
@@ -964,36 +1107,190 @@ gst_caps_structure_simplify (GstStructure * struct1,
 GstCaps *
 gst_caps_simplify (const GstCaps * caps)
 {
-  int i;
-  int j;
-  GstCaps *newcaps;
-  GstStructure *structure;
-  GstStructure *struct2;
+  GstCaps *ret;
 
-  if (gst_caps_get_size (caps) < 2) {
-    return gst_caps_copy (caps);
+  g_return_val_if_fail (caps != NULL, NULL);
+
+  ret = gst_caps_copy (caps);
+  gst_caps_do_simplify (ret);
+
+  return ret;
+}
+
+typedef struct
+{
+  GQuark name;
+  GValue value;
+  GstStructure *compare;
+}
+UnionField;
+
+static gboolean
+gst_caps_structure_figure_out_union (GQuark field_id, GValue * value,
+    gpointer user_data)
+{
+  UnionField *u = user_data;
+  const GValue *val = gst_structure_id_get_value (u->compare, field_id);
+
+  if (!val) {
+    if (u->name)
+      g_value_unset (&u->value);
+    return FALSE;
   }
+  if (gst_value_compare (val, value) == GST_VALUE_EQUAL)
+    return TRUE;
+  if (u->name) {
+    g_value_unset (&u->value);
+    return FALSE;
+  }
+  u->name = field_id;
+  gst_value_union (&u->value, val, value);
+  return TRUE;
+}
 
-  newcaps = gst_caps_new_empty ();
+static gboolean
+gst_caps_structure_simplify (GstStructure ** result,
+    const GstStructure * simplify, GstStructure * compare)
+{
+  GSList *list;
+  UnionField field = { 0, {0,}, NULL };
 
-  for (i = 0; i < gst_caps_get_size (caps); i++) {
-    structure = gst_caps_get_structure (caps, i);
+  /* try to subtract to get a real subset */
+  if (gst_caps_structure_subtract (&list, simplify, compare)) {
+    switch (g_slist_length (list)) {
+      case 0:
+        *result = NULL;
+        return TRUE;
+      case 1:
+        *result = list->data;
+        g_slist_free (list);
+        return TRUE;
+      default:
+      {
+        GSList *walk;
 
-    for (j = 0; j < gst_caps_get_size (newcaps); j++) {
-      struct2 = gst_caps_get_structure (caps, i);
-      if (gst_caps_structure_simplify (struct2, structure)) {
+        for (walk = list; walk; walk = g_slist_next (walk)) {
+          gst_structure_free (walk->data);
+        }
+        g_slist_free (list);
         break;
       }
     }
-    if (j == gst_caps_get_size (newcaps)) {
-      gst_caps_append_structure (newcaps, gst_structure_copy (structure));
+  }
+
+  /* try to union both structs */
+  field.compare = compare;
+  if (gst_structure_foreach ((GstStructure *) simplify,
+          gst_caps_structure_figure_out_union, &field)) {
+    gboolean ret = FALSE;
+
+    /* now we know all of simplify's fields are the same in compare
+     * but at most one field: field.name */
+    if (G_IS_VALUE (&field.value)) {
+      if (gst_structure_n_fields (simplify) == gst_structure_n_fields (compare)) {
+        gst_structure_id_set_value (compare, field.name, &field.value);
+        *result = NULL;
+        ret = TRUE;
+      }
+      g_value_unset (&field.value);
+    } else if (gst_structure_n_fields (simplify) <=
+        gst_structure_n_fields (compare)) {
+      /* compare is just more specific, will be optimized away later */
+      /* FIXME: do this here? */
+      GST_LOG ("found a case that will be optimized later.");
+    } else {
+      gchar *one = gst_structure_to_string (simplify);
+      gchar *two = gst_structure_to_string (compare);
+
+      GST_ERROR
+          ("caps mismatch: structures %s and %s claim to be possible to unify, but aren't",
+          one, two);
+      g_free (one);
+      g_free (two);
+    }
+    return ret;
+  }
+
+  return FALSE;
+}
+
+/**
+ * gst_caps_do_simplify:
+ * @caps: a #GstCaps to simplify
+ *
+ * Modifies the given @caps inplace into a representation that represents the 
+ * same set of formats, but in a simpler form.  Component structures that are 
+ * identical are merged.  Component structures that have values that can be 
+ * merged are also merged.
+ *
+ * Returns: TRUE, if the caps could be simplified
+ */
+gboolean
+gst_caps_do_simplify (GstCaps * caps)
+{
+  GstStructure *simplify, *compare, *result;
+  gint i, j, start;
+  gboolean changed = FALSE;
+
+  g_return_val_if_fail (caps != NULL, FALSE);
+
+  if (gst_caps_get_size (caps) < 2)
+    return FALSE;
+
+  g_ptr_array_sort (caps->structs, gst_caps_compare_structures);
+
+  start = caps->structs->len - 1;
+  for (i = caps->structs->len - 1; i >= 0; i--) {
+    simplify = gst_caps_get_structure (caps, i);
+    if (gst_structure_get_name_id (simplify) !=
+        gst_structure_get_name_id (gst_caps_get_structure (caps, start)))
+      start = i;
+    for (j = start; j >= 0; j--) {
+      if (j == i)
+        continue;
+      compare = gst_caps_get_structure (caps, j);
+      if (gst_structure_get_name_id (simplify) !=
+          gst_structure_get_name_id (compare)) {
+        break;
+      }
+      if (gst_caps_structure_simplify (&result, simplify, compare)) {
+#if 0
+        g_print ("%s  -  %s  =  %s\n",
+            gst_structure_to_string (simplify),
+            gst_structure_to_string (compare),
+            result ? gst_structure_to_string (result) : "---");
+#endif
+        if (result) {
+          gst_structure_free (simplify);
+          g_ptr_array_index (caps->structs, i) = result;
+          simplify = result;
+        } else {
+          gst_caps_remove_structure (caps, i);
+          start--;
+          break;
+        }
+        changed = TRUE;
+      }
     }
   }
 
-  return newcaps;
+  if (!changed)
+    return FALSE;
+
+  /* gst_caps_do_simplify (caps); */
+  return TRUE;
 }
 
 #ifndef GST_DISABLE_LOADSAVE
+/**
+ * gst_caps_save_thyself:
+ * @caps: a #GstCaps structure
+ * @parent: a XML parent node
+ *
+ * Serializes a #GstCaps to XML and adds it as a child node of @parent.
+ *
+ * Returns: a XML node pointer
+ */
 xmlNodePtr
 gst_caps_save_thyself (const GstCaps * caps, xmlNodePtr parent)
 {
@@ -1001,6 +1298,14 @@ gst_caps_save_thyself (const GstCaps * caps, xmlNodePtr parent)
   return 0;
 }
 
+/**
+ * gst_caps_load_thyself:
+ * @parent: a XML node
+ *
+ * Creates a #GstCaps from its XML serialization.
+ *
+ * Returns: a new #GstCaps structure
+ */
 GstCaps *
 gst_caps_load_thyself (xmlNodePtr parent)
 {
@@ -1038,9 +1343,9 @@ gst_caps_replace (GstCaps ** caps, GstCaps * newcaps)
  * @caps: a #GstCaps
  *
  * Converts @caps to a string representation.  This string representation
- * can be converted back to a #GstCaps by #gst_caps_from_string().
+ * can be converted back to a #GstCaps by #gst_caps_from_string.
  *
- * Returns: a string representing @caps
+ * Returns: a newly allocated string representing @caps.
  */
 gchar *
 gst_caps_to_string (const GstCaps * caps)
@@ -1091,11 +1396,12 @@ gst_caps_from_string_inplace (GstCaps * caps, const gchar * string)
   GstStructure *structure;
   gchar *s;
 
+  g_return_val_if_fail (string, FALSE);
   if (strcmp ("ANY", string) == 0) {
     caps->flags = GST_CAPS_FLAGS_ANY;
     return TRUE;
   }
-  if (strcmp ("NONE", string) == 0) {
+  if (strcmp ("EMPTY", string) == 0) {
     return TRUE;
   }
 
@@ -1127,11 +1433,11 @@ gst_caps_from_string_inplace (GstCaps * caps, const gchar * string)
 
 /**
  * gst_caps_from_string:
- * @caps: a string to convert to #GstCaps
+ * @string: a string to convert to #GstCaps
  *
  * Converts @caps from a string representation.
  *
- * Returns: a new #GstCaps
+ * Returns: a newly allocated #GstCaps
  */
 GstCaps *
 gst_caps_from_string (const gchar * string)
@@ -1150,8 +1456,11 @@ gst_caps_from_string (const gchar * string)
 static void
 gst_caps_transform_to_string (const GValue * src_value, GValue * dest_value)
 {
-  g_return_if_fail (src_value != NULL);
-  g_return_if_fail (dest_value != NULL);
+  g_return_if_fail (G_IS_VALUE (src_value));
+  g_return_if_fail (G_IS_VALUE (dest_value));
+  g_return_if_fail (G_VALUE_HOLDS (src_value, GST_TYPE_CAPS));
+  g_return_if_fail (G_VALUE_HOLDS (dest_value, G_TYPE_STRING)
+      || G_VALUE_HOLDS (dest_value, G_TYPE_POINTER));
 
   dest_value->data[0].v_pointer =
       gst_caps_to_string (src_value->data[0].v_pointer);
@@ -1169,6 +1478,17 @@ gst_caps_copy_conditional (const GstCaps * src)
 
 /* fixate utility functions */
 
+/**
+ * gst_caps_structure_fixate_field_nearest_int:
+ * @structure: a #GstStructure
+ * @field_name: a field in @structure
+ * @target: the target value of the fixation
+ *
+ * Fixates a #GstStructure by changing the given field to the nearest
+ * integer to @target that is a subset of the existing field.
+ *
+ * Returns: TRUE if the structure could be fixated
+ */
 gboolean
 gst_caps_structure_fixate_field_nearest_int (GstStructure * structure,
     const char *field_name, int target)
@@ -1205,7 +1525,7 @@ gst_caps_structure_fixate_field_nearest_int (GstStructure * structure,
       if (G_VALUE_TYPE (list_value) == G_TYPE_INT) {
         int x = g_value_get_int (list_value);
 
-        if (best_index == -1 || (ABS (target - x) < ABS (best - x))) {
+        if (best_index == -1 || (ABS (target - x) < ABS (target - best))) {
           best_index = i;
           best = x;
         }
@@ -1221,6 +1541,17 @@ gst_caps_structure_fixate_field_nearest_int (GstStructure * structure,
   return FALSE;
 }
 
+/**
+ * gst_caps_structure_fixate_field_nearest_double:
+ * @structure: a #GstStructure
+ * @field_name: a field in @structure
+ * @target: the target value of the fixation
+ *
+ * Fixates a #GstStructure by changing the given field to the nearest
+ * double to @target that is a subset of the existing field.
+ *
+ * Returns: TRUE if the structure could be fixated
+ */
 gboolean
 gst_caps_structure_fixate_field_nearest_double (GstStructure * structure,
     const char *field_name, double target)
@@ -1257,7 +1588,7 @@ gst_caps_structure_fixate_field_nearest_double (GstStructure * structure,
       if (G_VALUE_TYPE (list_value) == G_TYPE_DOUBLE) {
         double x = g_value_get_double (list_value);
 
-        if (best_index == -1 || (ABS (target - x) < ABS (best - x))) {
+        if (best_index == -1 || (ABS (target - x) < ABS (target - best))) {
           best_index = i;
           best = x;
         }
