@@ -20,10 +20,17 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 #include <sys/types.h>
 #include <sys/stat.h>
+#ifdef HAVE_DIRENT_H
 #include <dirent.h>
+#endif
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
+#endif
 #include <signal.h>
 
 #include "gst_private.h"
@@ -32,23 +39,21 @@
 #include "gstversion.h"
 #include "gstregistrypool.h"
 #include "gstinfo.h"
-#include "config.h"
 #include "gstfilter.h"
 
 
-#ifndef GST_DISABLE_GST_DEBUG
 #define GST_CAT_DEFAULT GST_CAT_PLUGIN_LOADING
-#else
-#define GST_CAT_DEFAULT 0
-#endif
 
 static GModule *main_module = NULL;
 static GList *_gst_plugin_static = NULL;
 
 /* static variables for segfault handling of plugin loading */
 static char *_gst_plugin_fault_handler_filename = NULL;
-extern gboolean *_gst_disable_segtrap; /* see gst.c */
+extern gboolean *_gst_disable_segtrap;  /* see gst.c */
+
+#ifndef HAVE_WIN32
 static gboolean *_gst_plugin_fault_handler_is_setup = FALSE;
+#endif
 
 /* list of valid licenses.
  * One of these must be specified or the plugin won't be loaded 
@@ -60,25 +65,24 @@ static gboolean *_gst_plugin_fault_handler_is_setup = FALSE;
  * QPL: http://www.trolltech.com/licenses/qpl.html
  */
 static gchar *valid_licenses[] = {
-  "LGPL",			/* GNU Lesser General Public License */
-  "GPL",			/* GNU General Public License */
-  "QPL",			/* Trolltech Qt Public License */
-  "GPL/QPL",			/* Combi-license of GPL + QPL */
-  GST_LICENSE_UNKNOWN,		/* some other license */
+  "LGPL",                       /* GNU Lesser General Public License */
+  "GPL",                        /* GNU General Public License */
+  "QPL",                        /* Trolltech Qt Public License */
+  "GPL/QPL",                    /* Combi-license of GPL + QPL */
+  GST_LICENSE_UNKNOWN,          /* some other license */
   NULL
 };
 
-static void		gst_plugin_desc_copy		(GstPluginDesc *dest, 
-							 const GstPluginDesc *src);
+static void gst_plugin_desc_copy (GstPluginDesc * dest,
+    const GstPluginDesc * src);
 
-static GstPlugin *	gst_plugin_register_func 	(GstPlugin *plugin, 
-							 GModule *module,
-							 GstPluginDesc *desc);
+static GstPlugin *gst_plugin_register_func (GstPlugin * plugin,
+    GModule * module, GstPluginDesc * desc);
 
 static GstPlugin *
-gst_plugin_copy (GstPlugin *plugin)
+gst_plugin_copy (GstPlugin * plugin)
 {
-  return g_memdup(plugin, sizeof(*plugin));
+  return g_memdup (plugin, sizeof (*plugin));
 }
 
 GType
@@ -94,10 +98,11 @@ gst_plugin_get_type (void)
   return plugin_type;
 }
 
-GQuark 
+GQuark
 gst_plugin_error_quark (void)
 {
   static GQuark quark = 0;
+
   if (!quark)
     quark = g_quark_from_static_string ("gst_plugin_error");
   return quark;
@@ -110,19 +115,22 @@ gst_plugin_error_quark (void)
  * When the main module is known, we can register the plugin right away.
  * */
 void
-_gst_plugin_register_static (GstPluginDesc *desc)
+_gst_plugin_register_static (GstPluginDesc * desc)
 {
   if (main_module == NULL) {
-    if (GST_CAT_DEFAULT) GST_LOG ("queueing static plugin \"%s\" for loading later on", desc->name);
+    if (GST_CAT_DEFAULT)
+      GST_LOG ("queueing static plugin \"%s\" for loading later on",
+          desc->name);
     _gst_plugin_static = g_list_prepend (_gst_plugin_static, desc);
-  }
-  else {
+  } else {
     GstPlugin *plugin;
 
-    if (GST_CAT_DEFAULT) GST_LOG ("attempting to load static plugin \"%s\" now...", desc->name);
+    if (GST_CAT_DEFAULT)
+      GST_LOG ("attempting to load static plugin \"%s\" now...", desc->name);
     plugin = g_new0 (GstPlugin, 1);
     if (gst_plugin_register_func (plugin, main_module, desc)) {
-      if (GST_CAT_DEFAULT) GST_INFO ("loaded static plugin \"%s\"", desc->name);
+      if (GST_CAT_DEFAULT)
+        GST_INFO ("loaded static plugin \"%s\"", desc->name);
       gst_registry_pool_add_plugin (plugin);
     }
   }
@@ -131,10 +139,11 @@ _gst_plugin_register_static (GstPluginDesc *desc)
 void
 _gst_plugin_initialize (void)
 {
-  main_module =  g_module_open (NULL, G_MODULE_BIND_LAZY);
+  main_module = g_module_open (NULL, G_MODULE_BIND_LAZY);
 
   /* now register all static plugins */
-  g_list_foreach (_gst_plugin_static, (GFunc) _gst_plugin_register_static, NULL);
+  g_list_foreach (_gst_plugin_static, (GFunc) _gst_plugin_register_static,
+      NULL);
 }
 
 /* this function could be extended to check if the plugin license matches the 
@@ -142,12 +151,12 @@ _gst_plugin_initialize (void)
  * We'll wait for someone who's interested in it to code it :)
  */
 static gboolean
-gst_plugin_check_license (const gchar *license)
+gst_plugin_check_license (const gchar * license)
 {
   gchar **check_license = valid_licenses;
 
   g_assert (check_license);
-  
+
   while (*check_license) {
     if (strcmp (license, *check_license) == 0)
       return TRUE;
@@ -161,50 +170,56 @@ gst_plugin_check_version (gint major, gint minor)
 {
   /* return NULL if the major and minor version numbers are not compatible */
   /* with ours. */
-  if (major != GST_VERSION_MAJOR || minor != GST_VERSION_MINOR) 
+  if (major != GST_VERSION_MAJOR || minor != GST_VERSION_MINOR)
     return FALSE;
 
   return TRUE;
 }
 
-static GstPlugin*
-gst_plugin_register_func (GstPlugin *plugin, GModule *module, GstPluginDesc *desc)
+static GstPlugin *
+gst_plugin_register_func (GstPlugin * plugin, GModule * module,
+    GstPluginDesc * desc)
 {
   g_assert (plugin->module == NULL);
 
   if (!gst_plugin_check_version (desc->major_version, desc->minor_version)) {
-    if (GST_CAT_DEFAULT) GST_INFO ("plugin \"%s\" has incompatible version, not loading",
-       plugin->filename);
+    if (GST_CAT_DEFAULT)
+      GST_INFO ("plugin \"%s\" has incompatible version, not loading",
+          plugin->filename);
     return FALSE;
   }
 
-  if (!desc->license || !desc->description || !desc->package ||
-      !desc->origin) {
-    if (GST_CAT_DEFAULT) GST_INFO ("plugin \"%s\" has incorrect GstPluginDesc, not loading",
-       plugin->filename);
+  if (!desc->license || !desc->description || !desc->package || !desc->origin) {
+    if (GST_CAT_DEFAULT)
+      GST_INFO ("plugin \"%s\" has incorrect GstPluginDesc, not loading",
+          plugin->filename);
     return FALSE;
   }
-      
+
   if (!gst_plugin_check_license (desc->license)) {
-    if (GST_CAT_DEFAULT) GST_INFO ("plugin \"%s\" has invalid license \"%s\", not loading",
-       plugin->filename, desc->license);
+    if (GST_CAT_DEFAULT)
+      GST_INFO ("plugin \"%s\" has invalid license \"%s\", not loading",
+          plugin->filename, desc->license);
     return FALSE;
   }
-  
+
   gst_plugin_desc_copy (&plugin->desc, desc);
   plugin->module = module;
 
   if (!((desc->plugin_init) (plugin))) {
-    if (GST_CAT_DEFAULT) GST_INFO ("plugin \"%s\" failed to initialise", plugin->filename);
+    if (GST_CAT_DEFAULT)
+      GST_INFO ("plugin \"%s\" failed to initialise", plugin->filename);
     plugin->module = NULL;
     return FALSE;
   }
-  
-  if (GST_CAT_DEFAULT) GST_LOG ("plugin \"%s\" initialised", GST_STR_NULL (plugin->filename));
+
+  if (GST_CAT_DEFAULT)
+    GST_LOG ("plugin \"%s\" initialised", GST_STR_NULL (plugin->filename));
 
   return plugin;
 }
 
+#ifndef HAVE_WIN32
 /*
  * _gst_plugin_fault_handler_restore:
  * segfault handler restorer
@@ -230,8 +245,7 @@ _gst_plugin_fault_handler_sighandler (int signum)
   /* We need to restore the fault handler or we'll keep getting it */
   _gst_plugin_fault_handler_restore ();
 
-  switch (signum)
-  {
+  switch (signum) {
     case SIGSEGV:
       g_print ("\nERROR: ");
       g_print ("Caught a segmentation fault while loading plugin file:\n");
@@ -257,30 +271,42 @@ _gst_plugin_fault_handler_setup (void)
   struct sigaction action;
 
   /* if asked to leave segfaults alone, just return */
-  if (_gst_disable_segtrap) return;
+  if (_gst_disable_segtrap)
+    return;
 
-  if (_gst_plugin_fault_handler_is_setup) return;
+  if (_gst_plugin_fault_handler_is_setup)
+    return;
 
   memset (&action, 0, sizeof (action));
   action.sa_handler = _gst_plugin_fault_handler_sighandler;
 
   sigaction (SIGSEGV, &action, NULL);
 }
+#else
+static void
+_gst_plugin_fault_handler_restore (void)
+{
+}
 
 static void
-_gst_plugin_fault_handler_setup ();
+_gst_plugin_fault_handler_setup (void)
+{
+}
+#endif
+
+static void _gst_plugin_fault_handler_setup ();
 
 /**
  * gst_plugin_load_file:
- * @plugin: The plugin to load
- * @error: Pointer to a NULL-valued GError.
+ * @filename: the plugin filename to load
+ * @error: pointer to a NULL-valued GError
  *
- * Load the given plugin.
+ * Loads the given plugin.
  *
  * Returns: a new GstPlugin or NULL, if an error occurred.
  */
 GstPlugin *
-gst_plugin_load_file (const gchar *filename, GError **error)
+gst_plugin_load_file (const gchar * filename, GError ** error)
 {
   GstPlugin *plugin;
   GModule *module;
@@ -290,22 +316,20 @@ gst_plugin_load_file (const gchar *filename, GError **error)
 
   g_return_val_if_fail (filename != NULL, NULL);
 
-  GST_CAT_DEBUG (GST_CAT_PLUGIN_LOADING, "attempt to load plugin \"%s\"", filename);
+  GST_CAT_DEBUG (GST_CAT_PLUGIN_LOADING, "attempt to load plugin \"%s\"",
+      filename);
 
   if (g_module_supported () == FALSE) {
     g_set_error (error,
-                 GST_PLUGIN_ERROR,
-                 GST_PLUGIN_ERROR_MODULE,
-                 "Dynamic loading not supported");
+        GST_PLUGIN_ERROR,
+        GST_PLUGIN_ERROR_MODULE, "Dynamic loading not supported");
     return NULL;
   }
 
   if (stat (filename, &file_status)) {
     g_set_error (error,
-                 GST_PLUGIN_ERROR,
-                 GST_PLUGIN_ERROR_MODULE,
-                 "Problem opening file %s\n",
-                 filename);
+        GST_PLUGIN_ERROR,
+        GST_PLUGIN_ERROR_MODULE, "Problem opening file %s\n", filename);
     return NULL;
   }
 
@@ -319,39 +343,40 @@ gst_plugin_load_file (const gchar *filename, GError **error)
 
       plugin = gst_registry_pool_find_plugin (desc->name);
       if (!plugin) {
-	free_plugin = TRUE;
-	plugin = g_new0 (GstPlugin, 1);
-	plugin->filename = g_strdup (filename);
-	GST_DEBUG ("created new GstPlugin %p for file \"%s\"", plugin, filename);
+        free_plugin = TRUE;
+        plugin = g_new0 (GstPlugin, 1);
+        plugin->filename = g_strdup (filename);
+        GST_DEBUG ("created new GstPlugin %p for file \"%s\"", plugin,
+            filename);
       } else {
-	free_plugin = FALSE;
-	if (gst_plugin_is_loaded (plugin)) {
-	  if (strcmp (plugin->filename, filename) != 0) {
-	    GST_WARNING ("plugin %p from file \"%s\" with same name %s is already "
-			 "loaded, aborting loading of \"%s\"", 
-			 plugin, plugin->filename, plugin->desc.name, filename);
-	    g_set_error (error,
-			 GST_PLUGIN_ERROR,
-			 GST_PLUGIN_ERROR_NAME_MISMATCH,
-			 "already a plugin with name \"%s\" loaded",
-			 desc->name);
-	    if (free_plugin) g_free (plugin);
-	    return NULL;
-	  }
-	  GST_LOG ("Plugin %p for file \"%s\" already loaded, returning it now", plugin, filename);
-	  return plugin;
-	}
+        free_plugin = FALSE;
+        if (gst_plugin_is_loaded (plugin)) {
+          if (plugin->filename && strcmp (plugin->filename, filename) != 0) {
+            GST_WARNING
+                ("plugin %p from file \"%s\" with same name %s is already "
+                "loaded, aborting loading of \"%s\"", plugin, plugin->filename,
+                plugin->desc.name, filename);
+            g_set_error (error, GST_PLUGIN_ERROR,
+                GST_PLUGIN_ERROR_NAME_MISMATCH,
+                "already a plugin with name \"%s\" loaded", desc->name);
+            if (free_plugin)
+              g_free (plugin);
+            return NULL;
+          }
+          GST_LOG ("Plugin %p for file \"%s\" already loaded, returning it now",
+              plugin, filename);
+          return plugin;
+        }
       }
-      GST_LOG ("Plugin %p for file \"%s\" prepared, calling entry function...", plugin, filename);
+      GST_LOG ("Plugin %p for file \"%s\" prepared, calling entry function...",
+          plugin, filename);
 
       if (g_module_symbol (module, "plugin_init", &ptr)) {
-        g_print ("plugin %p from file \"%s\" exports a symbol named plugin_init\n",
-                     plugin, plugin->filename);
-        g_set_error (error,
-                     GST_PLUGIN_ERROR,
-                     GST_PLUGIN_ERROR_NAME_MISMATCH,
-                     "plugin \"%s\" exports a symbol named plugin_init",
-                     desc->name);
+        g_print
+            ("plugin %p from file \"%s\" exports a symbol named plugin_init\n",
+            plugin, plugin->filename);
+        g_set_error (error, GST_PLUGIN_ERROR, GST_PLUGIN_ERROR_NAME_MISMATCH,
+            "plugin \"%s\" exports a symbol named plugin_init", desc->name);
       }
 
       /* this is where we load the actual .so, so let's trap SIGSEGV */
@@ -367,38 +392,36 @@ gst_plugin_load_file (const gchar *filename, GError **error)
       } else {
         /* remove signal handler */
         _gst_plugin_fault_handler_restore ();
-        GST_DEBUG ("gst_plugin_register_func failed for plugin \"%s\"", filename);
-	/* plugin == NULL */
+        GST_DEBUG ("gst_plugin_register_func failed for plugin \"%s\"",
+            filename);
+        /* plugin == NULL */
         g_set_error (error,
-                     GST_PLUGIN_ERROR,
-                     GST_PLUGIN_ERROR_MODULE,
-                     "gst_plugin_register_func failed for plugin \"%s\"",
-                     filename);
-	if (free_plugin) g_free (plugin);
+            GST_PLUGIN_ERROR,
+            GST_PLUGIN_ERROR_MODULE,
+            "gst_plugin_register_func failed for plugin \"%s\"", filename);
+        if (free_plugin)
+          g_free (plugin);
         return NULL;
       }
     } else {
       GST_DEBUG ("Could not find plugin entry point in \"%s\"", filename);
       g_set_error (error,
-                   GST_PLUGIN_ERROR,
-                   GST_PLUGIN_ERROR_MODULE,
-                   "Could not find plugin entry point in \"%s\"",
-                   filename);
+          GST_PLUGIN_ERROR,
+          GST_PLUGIN_ERROR_MODULE,
+          "Could not find plugin entry point in \"%s\"", filename);
     }
     return NULL;
   } else {
-    GST_DEBUG ("Error loading plugin %s, reason: %s\n", filename, g_module_error());
-    g_set_error (error,
-                 GST_PLUGIN_ERROR,
-                 GST_PLUGIN_ERROR_MODULE,
-                 "Error loading plugin %s, reason: %s\n",
-                 filename, g_module_error());
+    GST_DEBUG ("Error loading plugin %s, reason: %s\n", filename,
+        g_module_error ());
+    g_set_error (error, GST_PLUGIN_ERROR, GST_PLUGIN_ERROR_MODULE,
+        "Error loading plugin %s, reason: %s\n", filename, g_module_error ());
     return NULL;
   }
 }
 
 static void
-gst_plugin_desc_copy (GstPluginDesc *dest, const GstPluginDesc *src)
+gst_plugin_desc_copy (GstPluginDesc * dest, const GstPluginDesc * src)
 {
   dest->major_version = src->major_version;
   dest->minor_version = src->minor_version;
@@ -417,10 +440,11 @@ gst_plugin_desc_copy (GstPluginDesc *dest, const GstPluginDesc *src)
   g_free (dest->origin);
   dest->origin = g_strdup (src->origin);
 }
+
 #if 0
 /* unused */
 static void
-gst_plugin_desc_free (GstPluginDesc *desc)
+gst_plugin_desc_free (GstPluginDesc * desc)
 {
   g_free (desc->name);
   g_free (desc->description);
@@ -441,20 +465,21 @@ gst_plugin_desc_free (GstPluginDesc *desc)
  * Returns: whether or not the plugin unloaded
  */
 gboolean
-gst_plugin_unload_plugin (GstPlugin *plugin)
+gst_plugin_unload_plugin (GstPlugin * plugin)
 {
   g_return_val_if_fail (plugin != NULL, FALSE);
 
-  if (!plugin->module) 
+  if (!plugin->module)
     return TRUE;
 
   if (g_module_close (plugin->module)) {
     plugin->module = NULL;
-    GST_CAT_INFO (GST_CAT_PLUGIN_LOADING, "plugin \"%s\" unloaded", plugin->filename);
+    GST_CAT_INFO (GST_CAT_PLUGIN_LOADING, "plugin \"%s\" unloaded",
+        plugin->filename);
     return TRUE;
-  }
-  else {
-    GST_CAT_INFO (GST_CAT_PLUGIN_LOADING, "failed to unload plugin \"%s\"", plugin->filename);
+  } else {
+    GST_CAT_INFO (GST_CAT_PLUGIN_LOADING, "failed to unload plugin \"%s\"",
+        plugin->filename);
     return FALSE;
   }
 }
@@ -467,8 +492,8 @@ gst_plugin_unload_plugin (GstPlugin *plugin)
  *
  * Returns: the name of the plugin
  */
-const gchar*
-gst_plugin_get_name (GstPlugin *plugin)
+const gchar *
+gst_plugin_get_name (GstPlugin * plugin)
 {
   g_return_val_if_fail (plugin != NULL, NULL);
 
@@ -483,8 +508,8 @@ gst_plugin_get_name (GstPlugin *plugin)
  *
  * Returns: the long name of the plugin
  */
-G_CONST_RETURN gchar*
-gst_plugin_get_description (GstPlugin *plugin)
+G_CONST_RETURN gchar *
+gst_plugin_get_description (GstPlugin * plugin)
 {
   g_return_val_if_fail (plugin != NULL, NULL);
 
@@ -499,13 +524,14 @@ gst_plugin_get_description (GstPlugin *plugin)
  *
  * Returns: the filename of the plugin
  */
-G_CONST_RETURN gchar*
-gst_plugin_get_filename (GstPlugin *plugin)
+G_CONST_RETURN gchar *
+gst_plugin_get_filename (GstPlugin * plugin)
 {
   g_return_val_if_fail (plugin != NULL, NULL);
 
   return plugin->filename;
 }
+
 /**
  * gst_plugin_get_license:
  * @plugin: plugin to get the license of
@@ -514,13 +540,14 @@ gst_plugin_get_filename (GstPlugin *plugin)
  *
  * Returns: the license of the plugin
  */
-G_CONST_RETURN gchar*
-gst_plugin_get_license (GstPlugin *plugin)
+G_CONST_RETURN gchar *
+gst_plugin_get_license (GstPlugin * plugin)
 {
   g_return_val_if_fail (plugin != NULL, NULL);
 
   return plugin->desc.license;
 }
+
 /**
  * gst_plugin_get_package:
  * @plugin: plugin to get the package of
@@ -529,13 +556,14 @@ gst_plugin_get_license (GstPlugin *plugin)
  *
  * Returns: the package of the plugin
  */
-G_CONST_RETURN gchar*
-gst_plugin_get_package (GstPlugin *plugin)
+G_CONST_RETURN gchar *
+gst_plugin_get_package (GstPlugin * plugin)
 {
   g_return_val_if_fail (plugin != NULL, NULL);
 
   return plugin->desc.package;
 }
+
 /**
  * gst_plugin_get_origin:
  * @plugin: plugin to get the origin of
@@ -544,13 +572,14 @@ gst_plugin_get_package (GstPlugin *plugin)
  *
  * Returns: the origin of the plugin
  */
-G_CONST_RETURN gchar*
-gst_plugin_get_origin (GstPlugin *plugin)
+G_CONST_RETURN gchar *
+gst_plugin_get_origin (GstPlugin * plugin)
 {
   g_return_val_if_fail (plugin != NULL, NULL);
 
   return plugin->desc.origin;
 }
+
 /**
  * gst_plugin_get_module:
  * @plugin: plugin to query
@@ -562,12 +591,13 @@ gst_plugin_get_origin (GstPlugin *plugin)
  *          loaded yet.
  */
 GModule *
-gst_plugin_get_module (GstPlugin *plugin)
+gst_plugin_get_module (GstPlugin * plugin)
 {
   g_return_val_if_fail (plugin != NULL, FALSE);
 
   return plugin->module;
 }
+
 /**
  * gst_plugin_is_loaded:
  * @plugin: plugin to query
@@ -577,7 +607,7 @@ gst_plugin_get_module (GstPlugin *plugin)
  * Returns: TRUE is loaded, FALSE otherwise
  */
 gboolean
-gst_plugin_is_loaded (GstPlugin *plugin)
+gst_plugin_is_loaded (GstPlugin * plugin)
 {
   g_return_val_if_fail (plugin != NULL, FALSE);
 
@@ -597,30 +627,32 @@ gst_plugin_is_loaded (GstPlugin *plugin)
  *
  * Returns: a GList of features, g_list_free after use.
  */
-GList*
-gst_plugin_feature_filter (GstPlugin *plugin,
-		           GstPluginFeatureFilter filter,
-			   gboolean first,
-			   gpointer user_data)
+GList *
+gst_plugin_feature_filter (GstPlugin * plugin,
+    GstPluginFeatureFilter filter, gboolean first, gpointer user_data)
 {
-  return gst_filter_run (plugin->features, (GstFilterFunc) filter, first, user_data);
+  return gst_filter_run (plugin->features, (GstFilterFunc) filter, first,
+      user_data);
 }
 
 typedef struct
-{ 
+{
   GstPluginFeatureFilter filter;
-  gboolean               first;
-  gpointer               user_data;
-  GList                 *result;
-} FeatureFilterData;
+  gboolean first;
+  gpointer user_data;
+  GList *result;
+}
+FeatureFilterData;
 
 static gboolean
-_feature_filter (GstPlugin *plugin, gpointer user_data)
+_feature_filter (GstPlugin * plugin, gpointer user_data)
 {
   GList *result;
   FeatureFilterData *data = (FeatureFilterData *) user_data;
 
-  result = gst_plugin_feature_filter (plugin, data->filter, data->first, data->user_data);
+  result =
+      gst_plugin_feature_filter (plugin, data->filter, data->first,
+      data->user_data);
   if (result) {
     data->result = g_list_concat (data->result, result);
     return TRUE;
@@ -642,11 +674,9 @@ _feature_filter (GstPlugin *plugin, gpointer user_data)
  *
  * Returns: a GList of features, g_list_free after use.
  */
-GList*
-gst_plugin_list_feature_filter  (GList *list, 
-		                 GstPluginFeatureFilter filter,
-			         gboolean first,
-			         gpointer user_data)
+GList *
+gst_plugin_list_feature_filter (GList * list,
+    GstPluginFeatureFilter filter, gboolean first, gpointer user_data)
 {
   FeatureFilterData data;
   GList *result;
@@ -673,7 +703,7 @@ gst_plugin_list_feature_filter  (GList *list,
  * Returns: TRUE if the plugin is of the given name.
  */
 gboolean
-gst_plugin_name_filter (GstPlugin *plugin, const gchar *name)
+gst_plugin_name_filter (GstPlugin * plugin, const gchar * name)
 {
   return (plugin->desc.name && !strcmp (plugin->desc.name, name));
 }
@@ -688,8 +718,8 @@ gst_plugin_name_filter (GstPlugin *plugin, const gchar *name)
  *
  * Returns: a GstPluginFeature or NULL if the feature was not found.
  */
-GstPluginFeature*
-gst_plugin_find_feature (GstPlugin *plugin, const gchar *name, GType type)
+GstPluginFeature *
+gst_plugin_find_feature (GstPlugin * plugin, const gchar * name, GType type)
 {
   GList *walk;
   GstPluginFeature *result = NULL;
@@ -699,12 +729,11 @@ gst_plugin_find_feature (GstPlugin *plugin, const gchar *name, GType type)
 
   data.type = type;
   data.name = name;
-  
-  walk = gst_filter_run (plugin->features, 
-		         (GstFilterFunc) gst_plugin_feature_type_name_filter, TRUE,
-		         &data);
 
-  if (walk) 
+  walk = gst_filter_run (plugin->features,
+      (GstFilterFunc) gst_plugin_feature_type_name_filter, TRUE, &data);
+
+  if (walk)
     result = GST_PLUGIN_FEATURE (walk->data);
 
   return result;
@@ -720,7 +749,7 @@ gst_plugin_find_feature (GstPlugin *plugin, const gchar *name, GType type)
  * See #gst_plugin_get_feature_list
  */
 void
-gst_plugin_add_feature (GstPlugin *plugin, GstPluginFeature *feature)
+gst_plugin_add_feature (GstPlugin * plugin, GstPluginFeature * feature)
 {
   GstPluginFeature *oldfeature;
 
@@ -728,8 +757,8 @@ gst_plugin_add_feature (GstPlugin *plugin, GstPluginFeature *feature)
   g_return_if_fail (GST_IS_PLUGIN_FEATURE (feature));
   g_return_if_fail (feature != NULL);
 
-  oldfeature = gst_plugin_find_feature (plugin, 
-		  GST_PLUGIN_FEATURE_NAME (feature), G_OBJECT_TYPE (feature));
+  oldfeature = gst_plugin_find_feature (plugin,
+      GST_PLUGIN_FEATURE_NAME (feature), G_OBJECT_TYPE (feature));
 
   if (!oldfeature) {
     feature->manager = plugin;
@@ -746,8 +775,8 @@ gst_plugin_add_feature (GstPlugin *plugin, GstPluginFeature *feature)
  *
  * Returns: a GList of features, use g_list_free to free the list.
  */
-GList*
-gst_plugin_get_feature_list (GstPlugin *plugin)
+GList *
+gst_plugin_get_feature_list (GstPlugin * plugin)
 {
   g_return_val_if_fail (plugin != NULL, NULL);
 
@@ -763,7 +792,7 @@ gst_plugin_get_feature_list (GstPlugin *plugin)
  * Returns: whether the plugin was loaded or not
  */
 gboolean
-gst_plugin_load (const gchar *name)
+gst_plugin_load (const gchar * name)
 {
   GstPlugin *plugin;
   GError *error = NULL;
@@ -793,7 +822,7 @@ gst_plugin_load (const gchar *name)
  * Returns: whether the library was loaded or not
  */
 gboolean
-gst_library_load (const gchar *name)
+gst_library_load (const gchar * name)
 {
   gboolean res;
 
