@@ -1044,8 +1044,7 @@ gst_structure_to_abbr (GType type)
 static GType
 gst_structure_value_get_generic_type (GValue * val)
 {
-  if (G_VALUE_TYPE (val) == GST_TYPE_LIST
-      || G_VALUE_TYPE (val) == GST_TYPE_FIXED_LIST) {
+  if (G_VALUE_TYPE (val) == GST_TYPE_LIST || G_VALUE_TYPE (val) == GST_TYPE_FIXED_LIST) {
     GArray *array = g_value_peek_pointer (val);
 
     if (array->len > 0) {
@@ -1282,8 +1281,7 @@ gst_structure_parse_list (gchar * s, gchar ** after, GValue * value, GType type)
 }
 
 static gboolean
-gst_structure_parse_fixed_list (gchar * s, gchar ** after, GValue * value,
-    GType type)
+gst_structure_parse_fixed_list (gchar * s, gchar ** after, GValue * value, GType type)
 {
   return gst_structure_parse_any_list (s, after, value, type,
       GST_TYPE_FIXED_LIST, '<', '>');
