@@ -43,7 +43,8 @@ typedef struct
 
   GstTagMergeFunc merge_func;   /* functions to merge the values */
   GstTagFlag flag;              /* type of tag */
-} GstTagInfo;
+}
+GstTagInfo;
 
 #define TAGLIST "taglist"
 static GQuark gst_tag_list_quark;
@@ -263,8 +264,8 @@ gst_tag_lookup (GQuark entry)
  * This function takes ownership of all supplied variables.
  */
 void
-gst_tag_register (gchar * name, GstTagFlag flag, GType type,
-    gchar * nick, gchar * blurb, GstTagMergeFunc func)
+gst_tag_register (const gchar * name, GstTagFlag flag, GType type,
+    const gchar * nick, const gchar * blurb, GstTagMergeFunc func)
 {
   GQuark key;
   GstTagInfo *info;
@@ -281,8 +282,8 @@ gst_tag_register (gchar * name, GstTagFlag flag, GType type,
   info = g_new (GstTagInfo, 1);
   info->flag = flag;
   info->type = type;
-  info->nick = nick;
-  info->blurb = blurb;
+  info->nick = g_strdup (nick);
+  info->blurb = g_strdup (blurb);
   info->merge_func = func;
 
   TAG_LOCK;
@@ -372,6 +373,8 @@ gst_tag_get_description (const gchar * tag)
  * gst_tag_get_flag:
  * @tag: the tag
  *
+ * Gets the flag of @tag.
+ *
  * Returns the flag of this tag.
  */
 GstTagFlag
@@ -387,7 +390,7 @@ gst_tag_get_flag (const gchar * tag)
 }
 
 /**
- * gst_tag_list_is_fixed:
+ * gst_tag_is_fixed:
  * @tag: tag to check
  *
  * Checks if the given tag is fixed. A fixed tag can only contain one value.
@@ -439,7 +442,8 @@ typedef struct
 {
   GstStructure *list;
   GstTagMergeMode mode;
-} GstTagCopyData;
+}
+GstTagCopyData;
 static void
 gst_tag_list_add_value_internal (GstStructure * list, GstTagMergeMode mode,
     GQuark tag, GValue * value)
@@ -452,6 +456,7 @@ gst_tag_list_add_value_internal (GstStructure * list, GstTagMergeMode mode,
   if (info->merge_func
       && (value2 = gst_structure_id_get_value (list, tag)) != NULL) {
     GValue dest = { 0, };
+
     switch (mode) {
       case GST_TAG_MERGE_REPLACE_ALL:
       case GST_TAG_MERGE_REPLACE:
@@ -690,6 +695,7 @@ gst_tag_list_add_valist (GstTagList * list, GstTagMergeMode mode,
 
   while (tag != NULL) {
     GValue value = { 0, };
+
     quark = g_quark_from_string (tag);
     info = gst_tag_lookup (quark);
     if (info == NULL)
@@ -761,7 +767,8 @@ typedef struct
   GstTagForeachFunc func;
   GstTagList *tag_list;
   gpointer data;
-} TagForeachData;
+}
+TagForeachData;
 static int
 structure_foreach_wrapper (GQuark field_id, GValue * value, gpointer user_data)
 {
@@ -822,7 +829,7 @@ gst_event_new_tag (GstTagList * list)
 }
 
 /**
- * get_event_tag_get_list:
+ * gst_event_tag_get_list:
  * @tag_event: a tagging #GstEvent
  *
  * Gets the taglist from a given tagging event.
