@@ -24,10 +24,10 @@
 #include <string.h>
 #include <ctype.h>
 
+#include "gst_private.h"
 #include <gst/gst.h>
 #include <gobject/gvaluecollector.h>
 
-
 typedef struct _GstValueUnionInfo GstValueUnionInfo;
 struct _GstValueUnionInfo
 {
@@ -44,18 +44,86 @@ struct _GstValueIntersectInfo
   GstValueIntersectFunc func;
 };
 
+typedef struct _GstValueSubtractInfo GstValueSubtractInfo;
+struct _GstValueSubtractInfo
+{
+  GType minuend;
+  GType subtrahend;
+  GstValueSubtractFunc func;
+};
+
+GType gst_type_fourcc;
 GType gst_type_fourcc;
 GType gst_type_int_range;
 GType gst_type_double_range;
 GType gst_type_list;
+GType gst_type_fixed_list;
 
 static GArray *gst_value_table;
 static GArray *gst_value_union_funcs;
 static GArray *gst_value_intersect_funcs;
+static GArray *gst_value_subtract_funcs;
 
-/*************************************/
+/********/
 /* list */
+/********/
 
+/* two helper functions to serialize/stringify any type of list
+ * regular lists are done with { }, fixed lists with < >
+ */
+static char *
+gst_value_serialize_any_list (const GValue * value, const char *begin,
+    const char *end)
+{
+  int i;
+  GArray *array = value->data[0].v_pointer;
+  GString *s;
+  GValue *v;
+  gchar *s_val;
+
+  s = g_string_new (begin);
+  for (i = 0; i < array->len; i++) {
+    v = &g_array_index (array, GValue, i);
+    s_val = gst_value_serialize (v);
+    g_string_append (s, s_val);
+    g_free (s_val);
+    if (i < array->len - 1) {
+      g_string_append (s, ", ");
+    }
+  }
+  g_string_append (s, end);
+  return g_string_free (s, FALSE);
+}
+
+static void
+gst_value_transform_any_list_string (const GValue * src_value,
+    GValue * dest_value, const char *begin, const char *end)
+{
+  GValue *list_value;
+  GArray *array;
+  GString *s;
+  int i;
+  char *list_s;
+
+  array = src_value->data[0].v_pointer;
+
+  s = g_string_new (begin);
+  for (i = 0; i < array->len; i++) {
+    list_value = &g_array_index (array, GValue, i);
+
+    if (i != 0) {
+      g_string_append (s, ", ");
+    }
+    list_s = g_strdup_value_contents (list_value);
+    g_string_append (s, list_s);
+    g_free (list_s);
+  }
+  g_string_append (s, end);
+
+  dest_value->data[0].v_pointer = g_string_free (s, FALSE);
+}
+
+/* GValue functions usable for both regular lists and fixed lists */
 static void
 gst_value_init_list (GValue * value)
 {
@@ -150,9 +218,13 @@ gst_value_lcopy_list (const GValue * value, guint n_collect_values,
 void
 gst_value_list_prepend_value (GValue * value, const GValue * prepend_value)
 {
-  g_return_if_fail (GST_VALUE_HOLDS_LIST (value));
+  GValue val = { 0, };
 
-  g_array_prepend_vals ((GArray *) value->data[0].v_pointer, prepend_value, 1);
+  g_return_if_fail (GST_VALUE_HOLDS_LIST (value)
+      || GST_VALUE_HOLDS_FIXED_LIST (value));
+
+  gst_value_init_and_copy (&val, prepend_value);
+  g_array_prepend_vals ((GArray *) value->data[0].v_pointer, &val, 1);
 }
 
 /**
@@ -165,9 +237,13 @@ gst_value_list_prepend_value (GValue * value, const GValue * prepend_value)
 void
 gst_value_list_append_value (GValue * value, const GValue * append_value)
 {
-  g_return_if_fail (GST_VALUE_HOLDS_LIST (value));
+  GValue val = { 0, };
 
-  g_array_append_vals ((GArray *) value->data[0].v_pointer, append_value, 1);
+  g_return_if_fail (GST_VALUE_HOLDS_LIST (value)
+      || GST_VALUE_HOLDS_FIXED_LIST (value));
+
+  gst_value_init_and_copy (&val, append_value);
+  g_array_append_vals ((GArray *) value->data[0].v_pointer, &val, 1);
 }
 
 /**
@@ -181,7 +257,8 @@ gst_value_list_append_value (GValue * value, const GValue * append_value)
 guint
 gst_value_list_get_size (const GValue * value)
 {
-  g_return_val_if_fail (GST_VALUE_HOLDS_LIST (value), 0);
+  g_return_val_if_fail (GST_VALUE_HOLDS_LIST (value)
+      || GST_VALUE_HOLDS_FIXED_LIST (value), 0);
 
   return ((GArray *) value->data[0].v_pointer)->len;
 }
@@ -199,7 +276,8 @@ gst_value_list_get_size (const GValue * value)
 const GValue *
 gst_value_list_get_value (const GValue * value, guint index)
 {
-  g_return_val_if_fail (GST_VALUE_HOLDS_LIST (value), NULL);
+  g_return_val_if_fail (GST_VALUE_HOLDS_LIST (value)
+      || GST_VALUE_HOLDS_FIXED_LIST (value), NULL);
   g_return_val_if_fail (index < gst_value_list_get_size (value), NULL);
 
   return (const GValue *) &g_array_index ((GArray *) value->data[0].v_pointer,
@@ -258,28 +336,14 @@ gst_value_list_concat (GValue * dest, const GValue * value1,
 static void
 gst_value_transform_list_string (const GValue * src_value, GValue * dest_value)
 {
-  GValue *list_value;
-  GArray *array;
-  GString *s;
-  int i;
-  char *list_s;
+  gst_value_transform_any_list_string (src_value, dest_value, "{ ", " }");
+}
 
-  array = src_value->data[0].v_pointer;
-
-  s = g_string_new ("{ ");
-  for (i = 0; i < array->len; i++) {
-    list_value = &g_array_index (array, GValue, i);
-
-    if (i != 0) {
-      g_string_append (s, ", ");
-    }
-    list_s = g_strdup_value_contents (list_value);
-    g_string_append (s, list_s);
-    g_free (list_s);
-  }
-  g_string_append (s, " }");
-
-  dest_value->data[0].v_pointer = g_string_free (s, FALSE);
+static void
+gst_value_transform_fixed_list_string (const GValue * src_value,
+    GValue * dest_value)
+{
+  gst_value_transform_any_list_string (src_value, dest_value, "< ", " >");
 }
 
 static int
@@ -312,24 +376,7 @@ gst_value_compare_list (const GValue * value1, const GValue * value2)
 static char *
 gst_value_serialize_list (const GValue * value)
 {
-  int i;
-  GArray *array = value->data[0].v_pointer;
-  GString *s;
-  GValue *v;
-  gchar *s_val;
-
-  s = g_string_new ("{ ");
-  for (i = 0; i < array->len; i++) {
-    v = &g_array_index (array, GValue, i);
-    s_val = gst_value_serialize (v);
-    g_string_append (s, s_val);
-    g_free (s_val);
-    if (i < array->len - 1) {
-      g_string_append (s, ", ");
-    }
-  }
-  g_string_append (s, " }");
-  return g_string_free (s, FALSE);
+  return gst_value_serialize_any_list (value, "{ ", " }");
 }
 
 static gboolean
@@ -339,6 +386,19 @@ gst_value_deserialize_list (GValue * dest, const char *s)
   return FALSE;
 }
 
+static char *
+gst_value_serialize_fixed_list (const GValue * value)
+{
+  return gst_value_serialize_any_list (value, "< ", " >");
+}
+
+static gboolean
+gst_value_deserialize_fixed_list (GValue * dest, const char *s)
+{
+  g_warning ("unimplemented");
+  return FALSE;
+}
+
 /*************************************/
 /* fourcc */
 
@@ -579,7 +639,7 @@ static int
 gst_value_compare_int_range (const GValue * value1, const GValue * value2)
 {
   if (value2->data[0].v_int == value1->data[0].v_int &&
-      value2->data[0].v_int == value1->data[0].v_int)
+      value2->data[1].v_int == value1->data[1].v_int)
     return GST_VALUE_EQUAL;
   return GST_VALUE_UNORDERED;
 }
@@ -772,6 +832,25 @@ gst_value_get_caps (const GValue * value)
 /*************************************/
 /* GstBuffer */
 
+static int
+gst_value_compare_buffer (const GValue * value1, const GValue * value2)
+{
+  GstBuffer *buf1 = g_value_get_boxed (value1);
+  GstBuffer *buf2 = g_value_get_boxed (value2);
+
+  if (GST_BUFFER_SIZE (buf1) != GST_BUFFER_SIZE (buf2))
+    return GST_VALUE_UNORDERED;
+  if (GST_BUFFER_SIZE (buf1) == 0)
+    return GST_VALUE_EQUAL;
+  g_assert (GST_BUFFER_DATA (buf1));
+  g_assert (GST_BUFFER_DATA (buf2));
+  if (memcmp (GST_BUFFER_DATA (buf1), GST_BUFFER_DATA (buf2),
+          GST_BUFFER_SIZE (buf1)) == 0)
+    return GST_VALUE_EQUAL;
+
+  return GST_VALUE_UNORDERED;
+}
+
 static char *
 gst_value_serialize_buffer (const GValue * value)
 {
@@ -871,77 +950,161 @@ gst_value_deserialize_boolean (GValue * dest, const char *s)
 }
 
 /*************************************/
-/* int */
+/* ints */
 
 static int
-gst_value_compare_int (const GValue * value1, const GValue * value2)
+gst_strtoll (const char *s, char **end, int base)
 {
-  if (value1->data[0].v_int > value2->data[0].v_int)
-    return GST_VALUE_GREATER_THAN;
-  if (value1->data[0].v_int < value2->data[0].v_int)
-    return GST_VALUE_LESS_THAN;
-  return GST_VALUE_EQUAL;
-}
-
-static char *
-gst_value_serialize_int (const GValue * value)
-{
-  return g_strdup_printf ("%d", value->data[0].v_int);
-}
-
-static int
-gst_strtoi (const char *s, char **end, int base)
-{
-  int i;
+  long long i;
 
   if (s[0] == '-') {
-    i = -(int) strtoul (s + 1, end, base);
+    i = -(long long) g_ascii_strtoull (s + 1, end, base);
   } else {
-    i = strtoul (s, end, base);
+    i = g_ascii_strtoull (s, end, base);
   }
 
   return i;
 }
 
-static gboolean
-gst_value_deserialize_int (GValue * dest, const char *s)
-{
-  int x;
-  char *end;
-  gboolean ret = FALSE;
+#define CREATE_SERIALIZATION_START(_type,_macro) \
+static gint \
+gst_value_compare_ ## _type (const GValue * value1, const GValue * value2) \
+{ \
+  g ## _type val1 = g_value_get_ ## _type (value1); \
+  g ## _type val2 = g_value_get_ ## _type (value2); \
+  if (val1 > val2) \
+    return GST_VALUE_GREATER_THAN; \
+  if (val1 < val2) \
+    return GST_VALUE_LESS_THAN; \
+  return GST_VALUE_EQUAL; \
+} \
+\
+static char * \
+gst_value_serialize_ ## _type (const GValue * value) \
+{ \
+  GValue val = { 0, }; \
+  g_value_init (&val, G_TYPE_STRING); \
+  if (!g_value_transform (value, &val)) \
+    g_assert_not_reached (); \
+  /* NO_COPY_MADNESS!!! */ \
+  return (char *) g_value_get_string (&val); \
+}
 
-  x = gst_strtoi (s, &end, 0);
+static gboolean
+gst_value_deserialize_int_helper (long long *to, const char *s, long long min,
+    long long max)
+{
+  gboolean ret = FALSE;
+  char *end;
+
+  *to = gst_strtoll (s, &end, 0);
   if (*end == 0) {
     ret = TRUE;
   } else {
     if (g_ascii_strcasecmp (s, "little_endian") == 0) {
-      x = G_LITTLE_ENDIAN;
+      *to = G_LITTLE_ENDIAN;
       ret = TRUE;
     } else if (g_ascii_strcasecmp (s, "big_endian") == 0) {
-      x = G_BIG_ENDIAN;
+      *to = G_BIG_ENDIAN;
       ret = TRUE;
     } else if (g_ascii_strcasecmp (s, "byte_order") == 0) {
-      x = G_BYTE_ORDER;
+      *to = G_BYTE_ORDER;
       ret = TRUE;
     } else if (g_ascii_strcasecmp (s, "min") == 0) {
-      x = G_MININT;
+      *to = min;
       ret = TRUE;
     } else if (g_ascii_strcasecmp (s, "max") == 0) {
-      x = G_MAXINT;
+      *to = max;
       ret = TRUE;
     }
   }
   if (ret) {
-    g_value_set_int (dest, x);
+    if (*to < min || *to > max) {
+      ret = FALSE;
+    }
   }
   return ret;
 }
 
+#define CREATE_SERIALIZATION(_type,_macro) \
+CREATE_SERIALIZATION_START(_type,_macro) \
+\
+static gboolean \
+gst_value_deserialize_ ## _type (GValue * dest, const char *s) \
+{ \
+  long long x; \
+\
+  if (gst_value_deserialize_int_helper (&x, s, G_MIN ## _macro, G_MAX ## _macro)) { \
+    g_value_set_ ## _type (dest, x); \
+    return TRUE; \
+  } else { \
+    return FALSE; \
+  } \
+}
+
+#define CREATE_USERIALIZATION(_type,_macro) \
+CREATE_SERIALIZATION_START(_type,_macro) \
+\
+static gboolean \
+gst_value_deserialize_ ## _type (GValue * dest, const char *s) \
+{ \
+  unsigned long long x; \
+  char *end; \
+  gboolean ret = FALSE; \
+\
+  x = g_ascii_strtoull (s, &end, 0); \
+  if (*end == 0) { \
+    ret = TRUE; \
+  } else { \
+    if (g_ascii_strcasecmp (s, "little_endian") == 0) { \
+      x = G_LITTLE_ENDIAN; \
+      ret = TRUE; \
+    } else if (g_ascii_strcasecmp (s, "big_endian") == 0) { \
+      x = G_BIG_ENDIAN; \
+      ret = TRUE; \
+    } else if (g_ascii_strcasecmp (s, "byte_order") == 0) { \
+      x = G_BYTE_ORDER; \
+      ret = TRUE; \
+    } else if (g_ascii_strcasecmp (s, "min") == 0) { \
+      x = 0; \
+      ret = TRUE; \
+    } else if (g_ascii_strcasecmp (s, "max") == 0) { \
+      x = G_MAX ## _macro; \
+      ret = TRUE; \
+    } \
+  } \
+  if (ret) { \
+    if (x > G_MAX ## _macro) {\
+      ret = FALSE; \
+    } else { \
+      g_value_set_ ## _type (dest, x); \
+    } \
+  } \
+  return ret; \
+}
+
+#define REGISTER_SERIALIZATION(_gtype, _type) G_STMT_START{ \
+  static const GstValueTable gst_value = { \
+    _gtype, \
+    gst_value_compare_ ## _type, \
+    gst_value_serialize_ ## _type, \
+    gst_value_deserialize_ ## _type, \
+  }; \
+\
+  gst_value_register (&gst_value); \
+} G_STMT_END
+
+CREATE_SERIALIZATION (int, INT)
+    CREATE_SERIALIZATION (int64, INT64)
+    CREATE_SERIALIZATION (long, LONG)
+CREATE_USERIALIZATION (uint, UINT)
+CREATE_USERIALIZATION (uint64, UINT64)
+CREATE_USERIALIZATION (ulong, ULONG)
+
 /*************************************/
 /* double */
-
-static int
-gst_value_compare_double (const GValue * value1, const GValue * value2)
+     static int
+         gst_value_compare_double (const GValue * value1, const GValue * value2)
 {
   if (value1->data[0].v_double > value2->data[0].v_double)
     return GST_VALUE_GREATER_THAN;
@@ -986,6 +1149,57 @@ gst_value_deserialize_double (GValue * dest, const char *s)
   return ret;
 }
 
+/*************************************/
+/* float */
+
+static int
+gst_value_compare_float (const GValue * value1, const GValue * value2)
+{
+  if (value1->data[0].v_float > value2->data[0].v_float)
+    return GST_VALUE_GREATER_THAN;
+  if (value1->data[0].v_float < value2->data[0].v_float)
+    return GST_VALUE_LESS_THAN;
+  if (value1->data[0].v_float == value2->data[0].v_float)
+    return GST_VALUE_EQUAL;
+  return GST_VALUE_UNORDERED;
+}
+
+static char *
+gst_value_serialize_float (const GValue * value)
+{
+  char d[G_ASCII_DTOSTR_BUF_SIZE];
+
+  g_ascii_dtostr (d, G_ASCII_DTOSTR_BUF_SIZE, value->data[0].v_float);
+  return g_strdup (d);
+}
+
+static gboolean
+gst_value_deserialize_float (GValue * dest, const char *s)
+{
+  double x;
+  gboolean ret = FALSE;
+  char *end;
+
+  x = g_ascii_strtod (s, &end);
+  if (*end == 0) {
+    ret = TRUE;
+  } else {
+    if (g_ascii_strcasecmp (s, "min") == 0) {
+      x = -G_MAXFLOAT;
+      ret = TRUE;
+    } else if (g_ascii_strcasecmp (s, "max") == 0) {
+      x = G_MAXFLOAT;
+      ret = TRUE;
+    }
+  }
+  if (x > G_MAXFLOAT || x < -G_MAXFLOAT)
+    ret = FALSE;
+  if (ret) {
+    g_value_set_float (dest, x);
+  }
+  return ret;
+}
+
 /*************************************/
 /* string */
 
@@ -1068,6 +1282,64 @@ gst_value_deserialize_string (GValue * dest, const char *s)
   return TRUE;
 }
 
+/*************************************/
+/* enums */
+
+static int
+gst_value_compare_enum (const GValue * value1, const GValue * value2)
+{
+  GEnumValue *en1, *en2;
+  GEnumClass *klass1 = (GEnumClass *) g_type_class_peek (G_VALUE_TYPE (value1));
+  GEnumClass *klass2 = (GEnumClass *) g_type_class_peek (G_VALUE_TYPE (value2));
+
+  g_return_val_if_fail (klass1, GST_VALUE_UNORDERED);
+  g_return_val_if_fail (klass2, GST_VALUE_UNORDERED);
+  en1 = g_enum_get_value (klass1, g_value_get_enum (value1));
+  en2 = g_enum_get_value (klass2, g_value_get_enum (value2));
+  g_return_val_if_fail (en1, GST_VALUE_UNORDERED);
+  g_return_val_if_fail (en2, GST_VALUE_UNORDERED);
+  if (en1->value < en2->value)
+    return GST_VALUE_LESS_THAN;
+  if (en1->value > en2->value)
+    return GST_VALUE_GREATER_THAN;
+
+  return GST_VALUE_EQUAL;
+}
+
+static char *
+gst_value_serialize_enum (const GValue * value)
+{
+  GEnumValue *en;
+  GEnumClass *klass = (GEnumClass *) g_type_class_peek (G_VALUE_TYPE (value));
+
+  g_return_val_if_fail (klass, NULL);
+  en = g_enum_get_value (klass, g_value_get_enum (value));
+  g_return_val_if_fail (en, NULL);
+  return g_strdup (en->value_name);
+}
+
+static gboolean
+gst_value_deserialize_enum (GValue * dest, const char *s)
+{
+  GEnumValue *en;
+  gchar *endptr = NULL;
+  GEnumClass *klass = (GEnumClass *) g_type_class_peek (G_VALUE_TYPE (dest));
+
+  g_return_val_if_fail (klass, FALSE);
+  if (!(en = g_enum_get_value_by_name (klass, s))) {
+    if (!(en = g_enum_get_value_by_nick (klass, s))) {
+      gint i = strtol (s, &endptr, 0);
+
+      if (endptr && *endptr == '\0') {
+        en = g_enum_get_value (klass, i);
+      }
+    }
+  }
+  g_return_val_if_fail (en, FALSE);
+  g_value_set_enum (dest, en->value);
+  return TRUE;
+}
+
 /*************************************/
 /* unions */
 
@@ -1235,6 +1507,257 @@ gst_value_intersect_list (GValue * dest, const GValue * value1,
   return ret;
 }
 
+/*************************************/
+/* subtraction */
+
+static gboolean
+gst_value_subtract_int_int_range (GValue * dest, const GValue * minuend,
+    const GValue * subtrahend)
+{
+  int min = gst_value_get_int_range_min (subtrahend);
+  int max = gst_value_get_int_range_max (subtrahend);
+  int val = g_value_get_int (minuend);
+
+  if (val < min || val > max) {
+    gst_value_init_and_copy (dest, minuend);
+    return TRUE;
+  }
+  return FALSE;
+}
+
+static gboolean
+gst_value_create_new_range (GValue * dest, int min1, int max1, int min2,
+    int max2)
+{
+  GValue v1 = { 0, };
+  GValue v2 = { 0, };
+  GValue *pv1, *pv2;            /* yeah, hungarian! */
+
+  if (min1 <= max1 && min2 <= max2) {
+    pv1 = &v1;
+    pv2 = &v2;
+  } else if (min1 <= max1) {
+    pv1 = dest;
+    pv2 = NULL;
+  } else if (min2 <= max2) {
+    pv1 = NULL;
+    pv2 = dest;
+  } else {
+    return FALSE;
+  }
+
+  if (min1 < max1) {
+    g_value_init (pv1, GST_TYPE_INT_RANGE);
+    gst_value_set_int_range (pv1, min1, max1);
+  } else if (min1 == max1) {
+    g_value_init (pv1, G_TYPE_INT);
+    g_value_set_int (pv1, min1);
+  }
+  if (min2 < max2) {
+    g_value_init (pv2, GST_TYPE_INT_RANGE);
+    gst_value_set_int_range (pv2, min2, max2);
+  } else if (min2 == max2) {
+    g_value_init (pv2, G_TYPE_INT);
+    g_value_set_int (pv2, min2);
+  }
+
+  if (min1 <= max1 && min2 <= max2) {
+    gst_value_list_concat (dest, pv1, pv2);
+    g_value_unset (pv1);
+    g_value_unset (pv2);
+  }
+  return TRUE;
+}
+
+static gboolean
+gst_value_subtract_int_range_int (GValue * dest, const GValue * minuend,
+    const GValue * subtrahend)
+{
+  int min = gst_value_get_int_range_min (minuend);
+  int max = gst_value_get_int_range_max (minuend);
+  int val = g_value_get_int (subtrahend);
+
+  g_return_val_if_fail (min < max, FALSE);
+
+  if (val < min || val > max) {
+    gst_value_init_and_copy (dest, minuend);
+    return TRUE;
+  } else {
+    if (val == G_MAXINT) {
+      max--;
+      val--;
+    }
+    if (val == G_MININT) {
+      min++;
+      val++;
+    }
+    gst_value_create_new_range (dest, min, val - 1, val + 1, max);
+  }
+  return TRUE;
+}
+
+static gboolean
+gst_value_subtract_int_range_int_range (GValue * dest, const GValue * minuend,
+    const GValue * subtrahend)
+{
+  int min1 = gst_value_get_int_range_min (minuend);
+  int max1 = gst_value_get_int_range_max (minuend);
+  int min2 = gst_value_get_int_range_min (subtrahend);
+  int max2 = gst_value_get_int_range_max (subtrahend);
+
+  if (max2 == G_MAXINT && min2 == G_MININT) {
+    return FALSE;
+  } else if (max2 == G_MAXINT) {
+    return gst_value_create_new_range (dest, min1, MIN (min2 - 1, max1), 1, 0);
+  } else if (min2 == G_MININT) {
+    return gst_value_create_new_range (dest, MAX (max2 + 1, min1), max1, 1, 0);
+  } else {
+    return gst_value_create_new_range (dest, min1, MIN (min2 - 1, max1),
+        MAX (max2 + 1, min1), max1);
+  }
+}
+
+static gboolean
+gst_value_subtract_double_double_range (GValue * dest, const GValue * minuend,
+    const GValue * subtrahend)
+{
+  double min = gst_value_get_double_range_min (subtrahend);
+  double max = gst_value_get_double_range_max (subtrahend);
+  double val = g_value_get_double (minuend);
+
+  if (val < min || val > max) {
+    gst_value_init_and_copy (dest, minuend);
+    return TRUE;
+  }
+  return FALSE;
+}
+
+static gboolean
+gst_value_subtract_double_range_double (GValue * dest, const GValue * minuend,
+    const GValue * subtrahend)
+{
+  /* FIXME! */
+  gst_value_init_and_copy (dest, minuend);
+  return TRUE;
+}
+
+static gboolean
+gst_value_subtract_double_range_double_range (GValue * dest,
+    const GValue * minuend, const GValue * subtrahend)
+{
+  /* FIXME! */
+  /* done like with ints */
+  double min1 = gst_value_get_double_range_min (minuend);
+  double max2 = gst_value_get_double_range_max (minuend);
+  double max1 = MIN (gst_value_get_double_range_min (subtrahend), max2);
+  double min2 = MAX (gst_value_get_double_range_max (subtrahend), min1);
+  GValue v1 = { 0, };
+  GValue v2 = { 0, };
+  GValue *pv1, *pv2;            /* yeah, hungarian! */
+
+  if (min1 < max1 && min2 < max2) {
+    pv1 = &v1;
+    pv2 = &v2;
+  } else if (min1 < max1) {
+    pv1 = dest;
+    pv2 = NULL;
+  } else if (min2 < max2) {
+    pv1 = NULL;
+    pv2 = dest;
+  } else {
+    return FALSE;
+  }
+
+  if (min1 < max1) {
+    g_value_init (pv1, GST_TYPE_DOUBLE_RANGE);
+    gst_value_set_double_range (pv1, min1, max1);
+  }
+  if (min2 < max2) {
+    g_value_init (pv2, GST_TYPE_DOUBLE_RANGE);
+    gst_value_set_double_range (pv2, min2, max2);
+  }
+
+  if (min1 < max1 && min2 < max2) {
+    gst_value_list_concat (dest, pv1, pv2);
+    g_value_unset (pv1);
+    g_value_unset (pv2);
+  }
+  return TRUE;
+}
+
+static gboolean
+gst_value_subtract_from_list (GValue * dest, const GValue * minuend,
+    const GValue * subtrahend)
+{
+  guint i, size;
+  GValue subtraction = { 0, };
+  gboolean ret = FALSE;
+
+  g_return_val_if_fail (GST_VALUE_HOLDS_LIST (minuend), FALSE);
+
+  size = gst_value_list_get_size (minuend);
+  for (i = 0; i < size; i++) {
+    const GValue *cur = gst_value_list_get_value (minuend, i);
+
+    if (gst_value_subtract (&subtraction, cur, subtrahend)) {
+      if (!ret) {
+        gst_value_init_and_copy (dest, &subtraction);
+        ret = TRUE;
+      } else if (GST_VALUE_HOLDS_LIST (dest)
+          && GST_VALUE_HOLDS_LIST (&subtraction)) {
+        /* unroll */
+        GValue unroll = { 0, };
+
+        gst_value_init_and_copy (&unroll, dest);
+        g_value_unset (dest);
+        gst_value_list_concat (dest, &unroll, &subtraction);
+      } else if (GST_VALUE_HOLDS_LIST (dest)) {
+        gst_value_list_append_value (dest, &subtraction);
+      } else {
+        GValue temp = { 0, };
+
+        gst_value_init_and_copy (&temp, dest);
+        g_value_unset (dest);
+        gst_value_list_concat (dest, &temp, &subtraction);
+        g_value_unset (&temp);
+      }
+      g_value_unset (&subtraction);
+    }
+  }
+  return ret;
+}
+
+static gboolean
+gst_value_subtract_list (GValue * dest, const GValue * minuend,
+    const GValue * subtrahend)
+{
+  guint i, size;
+  GValue data[2] = { {0,}, {0,} };
+  GValue *subtraction = &data[0], *result = &data[1];
+
+  g_return_val_if_fail (GST_VALUE_HOLDS_LIST (subtrahend), FALSE);
+
+  gst_value_init_and_copy (result, minuend);
+  size = gst_value_list_get_size (subtrahend);
+  for (i = 0; i < size; i++) {
+    const GValue *cur = gst_value_list_get_value (subtrahend, i);
+
+    if (gst_value_subtract (subtraction, result, cur)) {
+      GValue *temp = result;
+
+      result = subtraction;
+      subtraction = temp;
+      g_value_unset (subtraction);
+    } else {
+      g_value_unset (result);
+      return FALSE;
+    }
+  }
+  gst_value_init_and_copy (dest, result);
+  g_value_unset (result);
+  return TRUE;
+}
+
 
 /*************************************/
 
@@ -1418,7 +1941,9 @@ gst_value_can_intersect (const GValue * value1, const GValue * value2)
         GstValueIntersectInfo, i);
     if (intersect_info->type1 == G_VALUE_TYPE (value1) &&
         intersect_info->type2 == G_VALUE_TYPE (value2))
-      return TRUE;
+      if (intersect_info->type2 == G_VALUE_TYPE (value1) &&
+          intersect_info->type1 == G_VALUE_TYPE (value2))
+        return TRUE;
   }
 
   return gst_value_can_compare (value1, value2);
@@ -1491,6 +2016,118 @@ gst_value_register_intersect_func (GType type1, GType type2,
   g_array_append_val (gst_value_intersect_funcs, intersect_info);
 }
 
+
+/* subtraction */
+
+/**
+ * gst_value_subtract:
+ * @dest: the destination value for the result if the subtraction is not empty
+ * @minuend: the value to subtract from
+ * @subtrahend: the value to subtract
+ *
+ * Subtracts @subtrahend from @minuend and stores the result in @dest.
+ * Note that this means subtraction as in sets, not as in mathematics.
+ *
+ * Returns: TRUE if the subtraction is not empty
+ */
+gboolean
+gst_value_subtract (GValue * dest, const GValue * minuend,
+    const GValue * subtrahend)
+{
+  GstValueSubtractInfo *info;
+  int i;
+
+  /* special cases first */
+  if (GST_VALUE_HOLDS_LIST (minuend))
+    return gst_value_subtract_from_list (dest, minuend, subtrahend);
+  if (GST_VALUE_HOLDS_LIST (subtrahend))
+    return gst_value_subtract_list (dest, minuend, subtrahend);
+
+  for (i = 0; i < gst_value_subtract_funcs->len; i++) {
+    info = &g_array_index (gst_value_subtract_funcs, GstValueSubtractInfo, i);
+    if (info->minuend == G_VALUE_TYPE (minuend) &&
+        info->subtrahend == G_VALUE_TYPE (subtrahend)) {
+      return info->func (dest, minuend, subtrahend);
+    }
+  }
+
+  if (gst_value_compare (minuend, subtrahend) != GST_VALUE_EQUAL) {
+    gst_value_init_and_copy (dest, minuend);
+    return TRUE;
+  }
+
+  return FALSE;
+}
+
+#if 0
+gboolean
+gst_value_subtract (GValue * dest, const GValue * minuend,
+    const GValue * subtrahend)
+{
+  gboolean ret = gst_value_subtract2 (dest, minuend, subtrahend);
+
+  g_printerr ("\"%s\"  -  \"%s\"  =  \"%s\"\n", gst_value_serialize (minuend),
+      gst_value_serialize (subtrahend),
+      ret ? gst_value_serialize (dest) : "---");
+  return ret;
+}
+#endif
+
+/**
+ * gst_value_can_subtract:
+ * @minuend: the value to subtract from
+ * @subtrahend: the value to subtract
+ *
+ * Checks if it's possible to subtract @subtrahend from @minuend.
+ *
+ * Returns: TRUE if a subtraction is possible
+ */
+gboolean
+gst_value_can_subtract (const GValue * minuend, const GValue * subtrahend)
+{
+  GstValueSubtractInfo *info;
+  int i;
+
+  /* special cases */
+  if (GST_VALUE_HOLDS_LIST (minuend) || GST_VALUE_HOLDS_LIST (subtrahend))
+    return TRUE;
+
+  for (i = 0; i < gst_value_subtract_funcs->len; i++) {
+    info = &g_array_index (gst_value_subtract_funcs, GstValueSubtractInfo, i);
+    if (info->minuend == G_VALUE_TYPE (minuend) &&
+        info->subtrahend == G_VALUE_TYPE (subtrahend))
+      return TRUE;
+  }
+
+  return gst_value_can_compare (minuend, subtrahend);
+}
+
+/**
+ * gst_value_register_subtract_func:
+ * @minuend_type: type of the minuend
+ * @subtrahend_type: type of the subtrahend
+ * @func: function to use
+ *
+ * Registers @func as a function capable of subtracting the values of 
+ * @subtrahend_type from values of @minuend_type.
+ */
+void
+gst_value_register_subtract_func (GType minuend_type, GType subtrahend_type,
+    GstValueSubtractFunc func)
+{
+  GstValueSubtractInfo info;
+
+  /* one type must be unfixed, other subtractions can be done as comparisons */
+  g_return_if_fail (!gst_type_is_fixed (minuend_type)
+      || !gst_type_is_fixed (subtrahend_type));
+
+  info.minuend = minuend_type;
+  info.subtrahend = subtrahend_type;
+  info.func = func;
+
+  g_array_append_val (gst_value_subtract_funcs, info);
+}
+
 /*
  * gst_value_register:
  * @table:
@@ -1517,29 +2154,45 @@ gst_value_init_and_copy (GValue * dest, const GValue * src)
 
 /*
  * gst_value_serialize:
- * @value:
+ * @value: a #GValue to serialize
  *
- * Returns:
+ * tries to transform the given @value into a string representation that allows
+ * getting back this string later on using gst_value_deserialize().
+ *
+ * Returns: the serialization for @value or NULL if none exists
  */
 gchar *
 gst_value_serialize (const GValue * value)
 {
   int i;
   GValue s_val = { 0 };
-  GstValueTable *table;
+  GstValueTable *table, *best = NULL;
   char *s;
 
+  g_return_val_if_fail (G_IS_VALUE (value), NULL);
+
   for (i = 0; i < gst_value_table->len; i++) {
     table = &g_array_index (gst_value_table, GstValueTable, i);
-    if (table->type != G_VALUE_TYPE (value) || table->serialize == NULL)
+    if (table->serialize == NULL)
       continue;
-
-    return table->serialize (value);
+    if (table->type == G_VALUE_TYPE (value)) {
+      best = table;
+      break;
+    }
+    if (g_type_is_a (G_VALUE_TYPE (value), table->type)) {
+      if (!best || g_type_is_a (table->type, best->type))
+        best = table;
+    }
   }
+  if (best)
+    return best->serialize (value);
 
   g_value_init (&s_val, G_TYPE_STRING);
-  g_value_transform (value, &s_val);
-  s = gst_string_wrap (g_value_get_string (&s_val));
+  if (g_value_transform (value, &s_val)) {
+    s = gst_string_wrap (g_value_get_string (&s_val));
+  } else {
+    s = NULL;
+  }
   g_value_unset (&s_val);
 
   return s;
@@ -1547,23 +2200,62 @@ gst_value_serialize (const GValue * value)
 
 /*
  * gst_value_deserialize:
- * @dest:
- * @src:
+ * @dest: #GValue to fill with contents of deserialization
+ * @src: string to deserialize
  *
- * Returns:
+ * Tries to deserialize a string into the type specified by the given GValue.
+ * If the operation succeeds, TRUE is returned, FALSE otherwise.
+ * 
+ * Returns: TRUE on success
  */
 gboolean
 gst_value_deserialize (GValue * dest, const gchar * src)
 {
-  GstValueTable *table;
+  GstValueTable *table, *best = NULL;
   int i;
 
+  g_return_val_if_fail (src != NULL, FALSE);
+  g_return_val_if_fail (G_IS_VALUE (dest), FALSE);
+
   for (i = 0; i < gst_value_table->len; i++) {
     table = &g_array_index (gst_value_table, GstValueTable, i);
-    if (table->type != G_VALUE_TYPE (dest) || table->deserialize == NULL)
+    if (table->serialize == NULL)
       continue;
+    if (table->type == G_VALUE_TYPE (dest)) {
+      best = table;
+      break;
+    }
+    if (g_type_is_a (G_VALUE_TYPE (dest), table->type)) {
+      if (!best || g_type_is_a (table->type, best->type))
+        best = table;
+    }
+  }
+  if (best)
+    return best->deserialize (dest, src);
 
-    return table->deserialize (dest, src);
+  return FALSE;
+}
+
+/*
+ * gst_type_is_fixed:
+ * @type:
+ *
+ * Returns:
+ */
+gboolean
+gst_type_is_fixed (GType type)
+{
+  if (type == GST_TYPE_INT_RANGE || type == GST_TYPE_DOUBLE_RANGE ||
+      type == GST_TYPE_LIST) {
+    return FALSE;
+  }
+  if (G_TYPE_IS_FUNDAMENTAL (type) &&
+      type < G_TYPE_MAKE_FUNDAMENTAL (G_TYPE_RESERVED_GLIB_LAST)) {
+    return TRUE;
+  }
+  if (type == GST_TYPE_BUFFER || type == GST_TYPE_FOURCC
+      || type == GST_TYPE_FIXED_LIST) {
+    return TRUE;
   }
 
   return FALSE;
@@ -1584,6 +2276,9 @@ _gst_value_initialize (void)
     NULL,
     NULL,
   };
+  GTypeFundamentalInfo finfo = {
+    0
+  };
 
   //const GTypeFundamentalInfo finfo = { G_TYPE_FLAG_DERIVABLE, };
 
@@ -1592,6 +2287,8 @@ _gst_value_initialize (void)
       sizeof (GstValueUnionInfo));
   gst_value_intersect_funcs = g_array_new (FALSE, FALSE,
       sizeof (GstValueIntersectInfo));
+  gst_value_subtract_funcs = g_array_new (FALSE, FALSE,
+      sizeof (GstValueSubtractInfo));
 
   {
     static const GTypeValueTable value_table = {
@@ -1612,8 +2309,8 @@ _gst_value_initialize (void)
     };
 
     info.value_table = &value_table;
-    gst_type_fourcc =
-        g_type_register_static (G_TYPE_BOXED, "GstFourcc", &info, 0);
+    gst_type_fourcc = g_type_register_fundamental (g_type_fundamental_next (),
+        "GstFourcc", &info, &finfo, 0);
     gst_value.type = gst_type_fourcc;
     gst_value_register (&gst_value);
   }
@@ -1638,7 +2335,8 @@ _gst_value_initialize (void)
 
     info.value_table = &value_table;
     gst_type_int_range =
-        g_type_register_static (G_TYPE_BOXED, "GstIntRange", &info, 0);
+        g_type_register_fundamental (g_type_fundamental_next (), "GstIntRange",
+        &info, &finfo, 0);
     gst_value.type = gst_type_int_range;
     gst_value_register (&gst_value);
   }
@@ -1663,7 +2361,8 @@ _gst_value_initialize (void)
 
     info.value_table = &value_table;
     gst_type_double_range =
-        g_type_register_static (G_TYPE_BOXED, "GstDoubleRange", &info, 0);
+        g_type_register_fundamental (g_type_fundamental_next (),
+        "GstDoubleRange", &info, &finfo, 0);
     gst_value.type = gst_type_double_range;
     gst_value_register (&gst_value);
   }
@@ -1687,12 +2386,38 @@ _gst_value_initialize (void)
     };
 
     info.value_table = &value_table;
-    gst_type_list =
-        g_type_register_static (G_TYPE_BOXED, "GstValueList", &info, 0);
+    gst_type_list = g_type_register_fundamental (g_type_fundamental_next (),
+        "GstValueList", &info, &finfo, 0);
     gst_value.type = gst_type_list;
     gst_value_register (&gst_value);
   }
 
+  {
+    static const GTypeValueTable value_table = {
+      gst_value_init_list,
+      gst_value_free_list,
+      gst_value_copy_list,
+      gst_value_list_peek_pointer,
+      "p",
+      gst_value_collect_list,
+      "p",
+      gst_value_lcopy_list
+    };
+    static GstValueTable gst_value = {
+      0,
+      gst_value_compare_list,
+      gst_value_serialize_fixed_list,
+      gst_value_deserialize_fixed_list,
+    };
+
+    info.value_table = &value_table;
+    gst_type_fixed_list =
+        g_type_register_fundamental (g_type_fundamental_next (),
+        "GstValueFixedList", &info, &finfo, 0);
+    gst_value.type = gst_type_fixed_list;
+    gst_value_register (&gst_value);
+  }
+
   {
 #if 0
     static const GTypeValueTable value_table = {
@@ -1708,7 +2433,7 @@ _gst_value_initialize (void)
 #endif
     static GstValueTable gst_value = {
       0,
-      NULL,                     /*gst_value_compare_buffer, */
+      gst_value_compare_buffer,
       gst_value_serialize_buffer,
       gst_value_deserialize_buffer,
     };
@@ -1722,49 +2447,21 @@ _gst_value_initialize (void)
     gst_value_register (&gst_value);
   }
 
-  {
-    static const GstValueTable gst_value = {
-      G_TYPE_INT,
-      gst_value_compare_int,
-      gst_value_serialize_int,
-      gst_value_deserialize_int,
-    };
+  REGISTER_SERIALIZATION (G_TYPE_DOUBLE, double);
+  REGISTER_SERIALIZATION (G_TYPE_FLOAT, float);
 
-    gst_value_register (&gst_value);
-  }
+  REGISTER_SERIALIZATION (G_TYPE_STRING, string);
+  REGISTER_SERIALIZATION (G_TYPE_BOOLEAN, boolean);
+  REGISTER_SERIALIZATION (G_TYPE_ENUM, enum);
 
-  {
-    static const GstValueTable gst_value = {
-      G_TYPE_DOUBLE,
-      gst_value_compare_double,
-      gst_value_serialize_double,
-      gst_value_deserialize_double,
-    };
+  REGISTER_SERIALIZATION (G_TYPE_INT, int);
 
-    gst_value_register (&gst_value);
-  }
+  REGISTER_SERIALIZATION (G_TYPE_INT64, int64);
+  REGISTER_SERIALIZATION (G_TYPE_LONG, long);
 
-  {
-    static const GstValueTable gst_value = {
-      G_TYPE_STRING,
-      gst_value_compare_string,
-      gst_value_serialize_string,
-      gst_value_deserialize_string,
-    };
-
-    gst_value_register (&gst_value);
-  }
-
-  {
-    static const GstValueTable gst_value = {
-      G_TYPE_BOOLEAN,
-      gst_value_compare_boolean,
-      gst_value_serialize_boolean,
-      gst_value_deserialize_boolean,
-    };
-
-    gst_value_register (&gst_value);
-  }
+  REGISTER_SERIALIZATION (G_TYPE_UINT, uint);
+  REGISTER_SERIALIZATION (G_TYPE_UINT64, uint64);
+  REGISTER_SERIALIZATION (G_TYPE_ULONG, ulong);
 
   g_value_register_transform_func (GST_TYPE_FOURCC, G_TYPE_STRING,
       gst_value_transform_fourcc_string);
@@ -1774,6 +2471,8 @@ _gst_value_initialize (void)
       gst_value_transform_double_range_string);
   g_value_register_transform_func (GST_TYPE_LIST, G_TYPE_STRING,
       gst_value_transform_list_string);
+  g_value_register_transform_func (GST_TYPE_FIXED_LIST, G_TYPE_STRING,
+      gst_value_transform_fixed_list_string);
 
   gst_value_register_intersect_func (G_TYPE_INT, GST_TYPE_INT_RANGE,
       gst_value_intersect_int_int_range);
@@ -1784,6 +2483,19 @@ _gst_value_initialize (void)
   gst_value_register_intersect_func (GST_TYPE_DOUBLE_RANGE,
       GST_TYPE_DOUBLE_RANGE, gst_value_intersect_double_range_double_range);
 
+  gst_value_register_subtract_func (G_TYPE_INT, GST_TYPE_INT_RANGE,
+      gst_value_subtract_int_int_range);
+  gst_value_register_subtract_func (GST_TYPE_INT_RANGE, G_TYPE_INT,
+      gst_value_subtract_int_range_int);
+  gst_value_register_subtract_func (GST_TYPE_INT_RANGE, GST_TYPE_INT_RANGE,
+      gst_value_subtract_int_range_int_range);
+  gst_value_register_subtract_func (G_TYPE_DOUBLE, GST_TYPE_DOUBLE_RANGE,
+      gst_value_subtract_double_double_range);
+  gst_value_register_subtract_func (GST_TYPE_DOUBLE_RANGE, G_TYPE_DOUBLE,
+      gst_value_subtract_double_range_double);
+  gst_value_register_subtract_func (GST_TYPE_DOUBLE_RANGE,
+      GST_TYPE_DOUBLE_RANGE, gst_value_subtract_double_range_double_range);
+
   gst_value_register_union_func (G_TYPE_INT, GST_TYPE_INT_RANGE,
       gst_value_union_int_int_range);
   gst_value_register_union_func (GST_TYPE_INT_RANGE, GST_TYPE_INT_RANGE,
