@@ -114,8 +114,6 @@ typedef struct
   CothreadPrivate *sink;
   /* current data */
   GstData *bufpen;
-  /* if this link needs a discont - FIXME: remove when core ready for this */
-  gboolean need_discont;
 }
 LinkPrivate;
 
@@ -132,6 +130,8 @@ struct _GstEntryScheduler
   GList *schedule_possible;     /* possible entry points */
   GList *waiting;               /* elements waiting for the clock */
   gboolean error;               /* if an element threw an error */
+
+  GSList *reaping;              /* cothreads we need to destroy but can't */
 };
 
 struct _GstEntrySchedulerClass
@@ -315,48 +315,14 @@ setup_loop (GstEntryScheduler * sched, GstElement * element)
  * CHAINBASED
  */
 
-/* this function returns the buffer currently in the bufpen
- * it's this complicated because we check that we don't need to invent 
- * a DISCONT event first. 
- * FIXME: The whole if part should go when the core supports this.
- */
 static GstData *
 get_buffer (GstEntryScheduler * sched, GstRealPad * pad)
 {
   LinkPrivate *priv = PAD_PRIVATE (pad);
-  GstData *data;
+  GstData *data = priv->bufpen;
 
-  g_assert (GST_PAD_IS_SINK (pad));
-  if (priv->need_discont && GST_IS_BUFFER (priv->bufpen)) {
-    if (GST_BUFFER_TIMESTAMP_IS_VALID (priv->bufpen)) {
-      data =
-          GST_DATA (gst_event_new_discontinuous (TRUE, GST_FORMAT_TIME,
-              GST_BUFFER_TIMESTAMP (priv->bufpen),
-              GST_BUFFER_OFFSET_IS_VALID (priv->
-                  bufpen) ? GST_FORMAT_DEFAULT : 0,
-              GST_BUFFER_OFFSET (priv->bufpen), 0));
-      GST_WARNING_OBJECT (sched,
-          "needed to invent a DISCONT (time %" G_GUINT64_FORMAT
-          ") for %s:%s => %s:%s, fix it please",
-          GST_BUFFER_TIMESTAMP (priv->bufpen),
-          GST_DEBUG_PAD_NAME (GST_PAD_PEER (pad)), GST_DEBUG_PAD_NAME (pad));
-    } else {
-      data = GST_DATA (gst_event_new_discontinuous (TRUE,
-              GST_BUFFER_OFFSET_IS_VALID (priv->
-                  bufpen) ? GST_FORMAT_DEFAULT : 0,
-              GST_BUFFER_OFFSET (priv->bufpen), 0));
-      GST_WARNING_OBJECT (sched,
-          "needed to invent a DISCONT (no time) for %s:%s => %s:%s, fix it please",
-          GST_DEBUG_PAD_NAME (GST_PAD_PEER (pad)), GST_DEBUG_PAD_NAME (pad));
-    }
-    sched->schedule_now = g_list_prepend (sched->schedule_now, priv);
-  } else {
-    data = priv->bufpen;
-    priv->bufpen = NULL;
-  }
+  priv->bufpen = NULL;
   g_assert (data);
-  if (GST_IS_EVENT (data) && GST_EVENT_TYPE (data) == GST_EVENT_DISCONTINUOUS)
-    priv->need_discont = FALSE;
   return data;
 }
 
@@ -378,12 +344,7 @@ gst_entry_scheduler_chain_wrapper (int argc, char **argv)
     if (pad->chainfunc) {
       GstData *data = get_buffer (priv->sched, pad);
 
-      if (GST_IS_EVENT (data)
-          && !GST_FLAG_IS_SET (element, GST_ELEMENT_EVENT_AWARE)) {
-        gst_pad_event_default (GST_PAD (pad), GST_EVENT (data));
-      } else {
-        pad->chainfunc (GST_PAD (pad), data);
-      }
+      gst_pad_call_chain_function (GST_PAD (pad), data);
       /* don't do anything after here with the pad, it might already be dead! 
          the element is still alive though */
     } else {
@@ -445,7 +406,7 @@ gst_entry_scheduler_get_wrapper (int argc, char **argv)
     GST_LOG_OBJECT (priv->sched, "calling getfunc for pad %s:%s",
         GST_DEBUG_PAD_NAME (pad));
     if (pad->getfunc) {
-      GstData *data = pad->getfunc (GST_PAD (pad));
+      GstData *data = gst_pad_call_get_function (GST_PAD (pad));
 
       /* make sure the pad still exists and is linked */
       if (!g_list_find (element->pads, pad)) {
@@ -470,7 +431,7 @@ gst_entry_scheduler_get_wrapper (int argc, char **argv)
           ("get-based element %s removed getfunc during processing",
               GST_OBJECT_NAME (element)));
     }
-    GST_LOG_OBJECT (priv->sched, "done calling chainfunc for element %s",
+    GST_LOG_OBJECT (priv->sched, "done calling getfunc for element %s",
         GST_ELEMENT_NAME (element));
 
     priv->wait = WAIT_FOR_PADS;
@@ -567,10 +528,37 @@ can_schedule (Entry * entry)
   }
 }
 
-#define safe_cothread_switch(sched,cothread) G_STMT_START{ \
-  if (do_cothread_get_current (sched->context) != cothread) \
-    do_cothread_switch (cothread); \
-}G_STMT_END
+static void
+safe_cothread_switch (GstEntryScheduler * scheduler, cothread * thread)
+{
+  GList *list;
+  cothread *cur = do_cothread_get_current (scheduler->context);
+
+  if (cur == thread) {
+    GST_LOG_OBJECT (scheduler, "switch to same cothread, ignoring");
+  }
+
+  for (list = scheduler->schedule_possible; list; list = g_list_next (list)) {
+    if (ENTRY_IS_COTHREAD (list->data)) {
+      CothreadPrivate *priv = (CothreadPrivate *) list->data;
+
+      if (priv->thread == thread)
+        gst_object_ref (GST_OBJECT (priv->element));
+      if (priv->thread == cur)
+        gst_object_unref (GST_OBJECT (priv->element));
+    }
+  }
+  do_cothread_switch (thread);
+  if (cur == do_cothread_get_main (scheduler->context)) {
+    GSList *walk;
+
+    for (walk = scheduler->reaping; walk; walk = g_slist_next (walk)) {
+      do_cothread_destroy (walk->data);
+    }
+    g_slist_free (scheduler->reaping);
+    scheduler->reaping = NULL;
+  }
+}
 
 /* the meat - no guarantee as to which cothread this function is called */
 static void
@@ -779,26 +767,48 @@ gst_entry_scheduler_setup (GstScheduler * sched)
   }
 }
 
+static void
+safe_cothread_destroy (CothreadPrivate * thread)
+{
+  GstEntryScheduler *scheduler = thread->sched;
+
+  if (do_cothread_get_current (scheduler->context) ==
+      do_cothread_get_main (scheduler->context)) {
+    do_cothread_destroy (thread->thread);
+  } else {
+    GST_WARNING_OBJECT (scheduler, "delaying destruction of cothread %p",
+        thread->thread);
+    scheduler->reaping = g_slist_prepend (scheduler->reaping, thread->thread);
+  }
+  thread->thread = NULL;
+}
+
+static void
+gst_entry_scheduler_remove_all_cothreads (GstEntryScheduler * scheduler)
+{
+  GList *list;
+
+  for (list = scheduler->schedule_possible; list; list = g_list_next (list)) {
+    if (ENTRY_IS_COTHREAD (list->data)) {
+      CothreadPrivate *priv = (CothreadPrivate *) list->data;
+
+      if (priv->thread)
+        safe_cothread_destroy (priv);
+    }
+  }
+}
+
 static void
 gst_entry_scheduler_reset (GstScheduler * sched)
 {
-#if 0
-  /* FIXME: do we need to destroy cothreads ourselves? */
-  GList *elements = GST_ENTRY_SCHEDULER (sched)->elements;
+  GstEntryScheduler *scheduler = GST_ENTRY_SCHEDULER (sched);
 
-  while (elements) {
-    GstElement *element = GST_ELEMENT (elements->data);
-
-    if (GST_ELEMENT_THREADSTATE (element)) {
-      do_cothread_destroy (GST_ELEMENT_THREADSTATE (element));
-      GST_ELEMENT_THREADSTATE (element) = NULL;
-    }
-    elements = g_list_next (elements);
+  if (scheduler->context) {
+    g_return_if_fail (scheduler->reaping == NULL);
+    gst_entry_scheduler_remove_all_cothreads (scheduler);
+    do_cothread_context_destroy (scheduler->context);
+    scheduler->context = NULL;
   }
-#endif
-
-  do_cothread_context_destroy (GST_ENTRY_SCHEDULER (sched)->context);
-  GST_ENTRY_SCHEDULER (sched)->context = NULL;
 }
 
 static CothreadPrivate *
@@ -852,7 +862,7 @@ _remove_cothread (CothreadPrivate * priv)
   sched->schedule_possible = g_list_remove (sched->schedule_possible, priv);
 
   if (priv->thread)
-    do_cothread_destroy (priv->thread);
+    safe_cothread_destroy (priv);
   g_free (priv);
 }
 
@@ -878,7 +888,6 @@ static GstElementStateReturn
 gst_entry_scheduler_state_transition (GstScheduler * scheduler,
     GstElement * element, gint transition)
 {
-  GList *list;
   GstEntryScheduler *sched = GST_ENTRY_SCHEDULER (scheduler);
 
   if (GST_FLAG_IS_SET (element, GST_ELEMENT_DECOUPLED))
@@ -889,15 +898,6 @@ gst_entry_scheduler_state_transition (GstScheduler * scheduler,
     case GST_STATE_NULL_TO_READY:
       break;
     case GST_STATE_READY_TO_PAUSED:
-      for (list = element->pads; list; list = g_list_next (list)) {
-        GstPad *pad = list->data;
-
-        if (!GST_IS_REAL_PAD (pad))
-          continue;
-        if (PAD_PRIVATE (pad)) {
-          PAD_PRIVATE (pad)->need_discont = TRUE;
-        }
-      }
       break;
     case GST_STATE_PAUSED_TO_PLAYING:
       break;
@@ -905,23 +905,11 @@ gst_entry_scheduler_state_transition (GstScheduler * scheduler,
       break;
     case GST_STATE_PAUSED_TO_READY:
       if (element == scheduler->parent) {
-        GList *list;
-
-        for (list = sched->schedule_possible; list; list = g_list_next (list)) {
-          if (ENTRY_IS_COTHREAD (list->data)) {
-            CothreadPrivate *priv = (CothreadPrivate *) list->data;
-
-            if (priv->thread) {
-              do_cothread_destroy (priv->thread);
-              priv->thread = NULL;
-            }
-          }
-        }
+        gst_entry_scheduler_remove_all_cothreads (sched);
       }
       if (element->sched_private != NULL
           && ELEMENT_PRIVATE (element)->thread != NULL) {
-        do_cothread_destroy (ELEMENT_PRIVATE (element)->thread);
-        ELEMENT_PRIVATE (element)->thread = NULL;
+        safe_cothread_destroy (ELEMENT_PRIVATE (element));
       }
       break;
     case GST_STATE_READY_TO_NULL:
@@ -938,7 +926,10 @@ gst_entry_scheduler_state_transition (GstScheduler * scheduler,
 static gboolean
 gst_entry_scheduler_yield (GstScheduler * sched, GstElement * element)
 {
-  g_assert (ELEMENT_PRIVATE (element));
+  /* g_assert (ELEMENT_PRIVATE (element)); */
+  /* FIXME: queue thinks it may just interrupt, is that ok? */
+  if (!ELEMENT_PRIVATE (element))
+    return TRUE;
   ELEMENT_PRIVATE (element)->wait = WAIT_FOR_NOTHING;
   schedule_next_element (GST_ENTRY_SCHEDULER (sched));
   return FALSE;
@@ -967,7 +958,6 @@ gst_entry_scheduler_pad_link (GstScheduler * scheduler, GstPad * srcpad,
 
   priv = g_new0 (LinkPrivate, 1);
   priv->entry.type = ENTRY_LINK;
-  priv->need_discont = TRUE;
   /* wrap srcpad */
   element = gst_pad_get_parent (srcpad);
   priv->srcpad = GST_REAL_PAD (srcpad);
