@@ -23,7 +23,6 @@
 #define __GST_DPMAN_H__
 
 #include <gst/gstobject.h>
-#include <gst/gstprops.h>
 #include <gst/control/dparamcommon.h>
 #include <gst/control/dparam.h>
 #include <gst/control/unitconvert.h>
@@ -50,7 +49,7 @@ G_BEGIN_DECLS
 typedef enum {
   GST_DPMAN_CALLBACK,
   GST_DPMAN_DIRECT,
-  GST_DPMAN_ARRAY,
+  GST_DPMAN_ARRAY
 } GstDPMUpdateMethod;
 
 typedef struct _GstDParamManagerClass GstDParamManagerClass;
