@@ -1,22 +1,23 @@
 #include <gst/gst.h>
 
-int main (int argc, char *argv[]) 
+int
+main (int argc, char *argv[])
 {
   GstElement *pipeline, *thread, *queue, *src, *sink;
 
   gst_init (&argc, &argv);
 
-  free (malloc (8)); /* -lefence */
+  free (malloc (8));            /* -lefence */
 
   pipeline = gst_pipeline_new ("pipeline");
 
   src = gst_element_factory_make ("fakesrc", "src");
 
   thread = gst_thread_new ("thread");
-  
+
   queue = gst_element_factory_make ("queue", "queue");
   sink = gst_element_factory_make ("fakesink", "sink");
-    
+
   gst_bin_add (GST_BIN (thread), queue);
   gst_bin_add (GST_BIN (thread), sink);
   gst_bin_add (GST_BIN (pipeline), thread);
