@@ -15,7 +15,8 @@ typedef struct
   gchar *bs_accesspattern;
 
   gboolean integrity_check;
-} TestParam;
+}
+TestParam;
 
 static GSList *params = NULL;
 
@@ -26,41 +27,41 @@ static gboolean verbose = FALSE;
 static gboolean dump = FALSE;
 
 static void
-handoff (GstElement *element, GstBuffer *buf, GstPad *pad, gpointer data)
+handoff (GstElement * element, GstBuffer * buf, GstPad * pad, gpointer data)
 {
   if (GST_IS_BUFFER (buf)) {
     if (integrity_check) {
       gint i;
       guint8 *ptr = GST_BUFFER_DATA (buf);
-    
-      for (i=0; i<GST_BUFFER_SIZE (buf); i++) {
+
+      for (i = 0; i < GST_BUFFER_SIZE (buf); i++) {
         if (*ptr++ != count++) {
-	  g_print ("data error!\n");
-	  return;
+          g_print ("data error!\n");
+          return;
         }
       }
     }
-  }
-  else {
+  } else {
     g_print ("not a buffer ! %p\n", buf);
   }
 }
-static gchar*
-create_desc (TestParam *param) 
+static gchar *
+create_desc (TestParam * param)
 {
   gchar *desc;
 
-  desc = g_strdup_printf ("%s %s, pattern %s",  (param->src_sizetype == 2 ? "fixed" : "random"), 
-		  				(param->src_data == 1 ? "src" : "subbuffer"),
-						param->bs_accesspattern);
+  desc =
+      g_strdup_printf ("%s %s, pattern %s",
+      (param->src_sizetype == 2 ? "fixed" : "random"),
+      (param->src_data == 1 ? "src" : "subbuffer"), param->bs_accesspattern);
   return desc;
 }
 
-static gboolean 
-read_param_file (gchar *filename) 
+static gboolean
+read_param_file (gchar * filename)
 {
   FILE *fp;
-  gchar line[MAX_CONFIG_LINE+1];
+  gchar line[MAX_CONFIG_LINE + 1];
   guint linenr = 0;
   gchar pattern[MAX_CONFIG_PATTERN];
   gint data, sizetype, integrity_check;
@@ -68,23 +69,23 @@ read_param_file (gchar *filename)
   gboolean res = TRUE;
 
   fp = fopen (filename, "r");
-  if (fp == NULL) 
+  if (fp == NULL)
     return FALSE;
 
-  scan_str = g_strdup_printf ("%%d %%d %%%ds %%d", MAX_CONFIG_PATTERN-1);
-  
-  while (fgets (line, MAX_CONFIG_LINE, fp)) { 
+  scan_str = g_strdup_printf ("%%d %%d %%%ds %%d", MAX_CONFIG_PATTERN - 1);
+
+  while (fgets (line, MAX_CONFIG_LINE, fp)) {
     linenr++;
 
     if (line[0] == '\n' || line[0] == '#')
       continue;
 
-    if (sscanf (line, scan_str, &data, &sizetype, pattern, &integrity_check) != 4) {
+    if (sscanf (line, scan_str, &data, &sizetype, pattern,
+            &integrity_check) != 4) {
       g_print ("error on line: %d\n", linenr);
       res = FALSE;
       break;
-    }
-    else {
+    } else {
       TestParam *param = g_malloc (sizeof (TestParam));
 
       param->src_data = data;
@@ -96,12 +97,12 @@ read_param_file (gchar *filename)
     }
   }
   g_free (scan_str);
-  
+
   return res;
 }
 
-static void 
-run_test (GstBin *pipeline, gint iters)
+static void
+run_test (GstBin * pipeline, gint iters)
 {
   gint vm = 0;
   gint maxiters = iters;
@@ -114,28 +115,31 @@ run_test (GstBin *pipeline, gint iters)
     gint newvm = gst_alloc_trace_live_all ();
     gint percent;
 
-    percent = (gint)((maxiters-iters+1)*100.0/maxiters);
+    percent = (gint) ((maxiters - iters + 1) * 100.0 / maxiters);
 
     if (percent != prev_percent || newvm - vm > VM_THRES) {
-      g_print ("\r%d (delta %d) %.3d%%               ", newvm, newvm - vm, percent);
+      g_print ("\r%d (delta %d) %.3d%%               ", newvm, newvm - vm,
+          percent);
       prev_percent = percent;
       vm = newvm;
     }
     gst_bin_iterate (pipeline);
 
-    if (iters > 0) iters--;
+    if (iters > 0)
+      iters--;
   }
   gst_element_set_state (GST_ELEMENT (pipeline), GST_STATE_NULL);
 }
 
-static void 
+static void
 usage (char *argv[])
 {
-  g_print ("usage: %s [--verbose] [--dump] <paramfile> <iterations>\n", argv[0]);
+  g_print ("usage: %s [--verbose] [--dump] <paramfile> <iterations>\n",
+      argv[0]);
 }
 
 int
-main (int argc, char *argv[]) 
+main (int argc, char *argv[])
 {
   GstElement *src;
   GstElement *sink;
@@ -149,7 +153,7 @@ main (int argc, char *argv[])
   gst_init (&argc, &argv);
 
   arg_walk = 1;
-  while ((arg_walk < argc)  && (argv[arg_walk][0] == '-')) {
+  while ((arg_walk < argc) && (argv[arg_walk][0] == '-')) {
     if (!strncmp (argv[arg_walk], "--verbose", 9))
       verbose = TRUE;
     else if (!strncmp (argv[arg_walk], "--dump", 6))
@@ -161,10 +165,10 @@ main (int argc, char *argv[])
     arg_walk++;
   }
   if (argc - arg_walk < 2) {
-    usage(argv);
+    usage (argv);
     return -1;
   }
-  if (!read_param_file (argv[arg_walk])) { 
+  if (!read_param_file (argv[arg_walk])) {
     g_print ("error reading file %s\n", argv[arg_walk]);
     usage (argv);
     return -1;
@@ -186,9 +190,9 @@ main (int argc, char *argv[])
   bs = gst_element_factory_make ("bstest", "bs");
   g_assert (bs);
 
-  gst_element_link_many (src, bs, sink);
+  gst_element_link_many (src, bs, sink, NULL);
 
-  gst_bin_add_many (GST_BIN (pipeline), src, bs, sink);
+  gst_bin_add_many (GST_BIN (pipeline), src, bs, sink, NULL);
 
   walk = params;
 
@@ -198,21 +202,19 @@ main (int argc, char *argv[])
 
     integrity_check = param->integrity_check;
 
-    g_print ("\n\nrunning test %d (%d iterations):\n", testnum+1, iterations);
+    g_print ("\n\nrunning test %d (%d iterations):\n", testnum + 1, iterations);
     desc = create_desc (param);
     g_print ("%s\n", desc);
     g_free (desc);
 
-    g_object_set (G_OBJECT (src), "data", param->src_data, 
-		                  "sizetype", param->src_sizetype, 
-				  "filltype", (integrity_check?5:0),
-				  "silent", !verbose, NULL);
+    g_object_set (G_OBJECT (src), "data", param->src_data,
+        "sizetype", param->src_sizetype,
+        "filltype", (integrity_check ? 5 : 0), "silent", !verbose, NULL);
 
-    g_object_set (G_OBJECT (bs),  "accesspattern", param->bs_accesspattern, 
-				  "silent", !verbose, NULL);
+    g_object_set (G_OBJECT (bs), "accesspattern", param->bs_accesspattern,
+        "silent", !verbose, NULL);
 
-    g_object_set (G_OBJECT (sink), "dump", dump,
-		     		   "silent", !verbose, NULL);
+    g_object_set (G_OBJECT (sink), "dump", dump, "silent", !verbose, NULL);
 
     run_test (GST_BIN (pipeline), iterations);
 
