@@ -15,15 +15,17 @@ gboolean FOUND = FALSE;
 gchar *filename = NULL;
 
 void
-gst_caps_print (const char *filename, const GstCaps *caps)
+gst_caps_print (const char *filename, const GstCaps * caps)
 {
   gchar *caps_str = gst_caps_to_string (caps);
+
   g_print ("%s - %s\n", filename, caps_str);
   g_free (caps_str);
 }
 
 void
-have_type_handler (GstElement *typefind, guint probability, const GstCaps *caps, gpointer unused)
+have_type_handler (GstElement * typefind, guint probability,
+    const GstCaps * caps, gpointer unused)
 {
   gst_caps_print (filename, caps);
   FOUND = TRUE;
@@ -40,11 +42,11 @@ main (int argc, char *argv[])
 
   gst_init (&argc, &argv);
 
-  if (argc < 2) { 
+  if (argc < 2) {
     g_print ("Please give a filename to typefind\n\n");
     return 1;
   }
-  
+
   pipeline = gst_pipeline_new (NULL);
   source = gst_element_factory_make ("filesrc", "source");
   g_assert (GST_IS_ELEMENT (source));
@@ -52,8 +54,8 @@ main (int argc, char *argv[])
   g_assert (GST_IS_ELEMENT (typefind));
   gst_bin_add_many (GST_BIN (pipeline), source, typefind, NULL);
   gst_element_link (source, typefind);
-  g_signal_connect (G_OBJECT (typefind), "have-type", 
-		    G_CALLBACK (have_type_handler), NULL);
+  g_signal_connect (G_OBJECT (typefind), "have-type",
+      G_CALLBACK (have_type_handler), NULL);
 
   while (i < argc) {
     FOUND = FALSE;
@@ -63,9 +65,9 @@ main (int argc, char *argv[])
     /* set to play */
     gst_element_set_state (GST_ELEMENT (pipeline), GST_STATE_PLAYING);
 
-    while (!FOUND) { 
+    while (!FOUND) {
       if (!gst_bin_iterate (GST_BIN (pipeline)))
-	break;
+        break;
     }
     if (!FOUND) {
       g_print ("%s - No type found\n", argv[i]);
